Struct zoom_api::groups::Groups

source ·
pub struct Groups {
    pub client: Client,
}

Fields

client: Client

Implementations

List groups.

This function performs a GET to the /groups endpoint.

List groups under an account.

Prerequisite: Pro or higher account.
Scopes: group:read:admin

Rate Limit Label: Medium

Create a group.

This function performs a POST to the /groups endpoint.

Create a group under an account.

You can add a maximum of 100 groups in one account per day. If you go over, you will get an error. You can add a maximum of 5000 groups in one account.

Prerequisite: Pro or higher account.
Scopes: group:write:admin

Rate Limit Label: Light

Get a group.

This function performs a GET to the /groups/{groupId} endpoint.

Get a group under an account.

Prerequisite: Pro, Business, or Education account
Scopes: group:read:admin

Rate Limit Label: Light

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.

Delete a group.

This function performs a DELETE to the /groups/{groupId} endpoint.

Delete a group.

Prerequisite: Pro, Business, or Education account
Scopes: group:write:admin

Rate Limit Label: Light

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.

Update a group.

This function performs a PATCH to the /groups/{groupId} endpoint.

Update a group under your account.

Prerequisite: Pro, Business, or Education account
Scopes: group:write:admin

Rate Limit Label: Light

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.

List group members .

This function performs a GET to the /groups/{groupId}/members endpoint.

List the members of a group under your account.

Prerequisite: Pro, Business, or Education account
Scopes: group:read:admin

Rate Limit Label: Medium

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.

  • page_size: i64 – The number of records returned within a single API call.

  • page_number: i64Deprecated - This field has been deprecated and we will stop supporting it completely in a future release. Please use “next_page_token” for pagination instead of this field.

    The page number of the current page in the returned records.

  • next_page_token: &str – The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.

List group members .

This function performs a GET to the /groups/{groupId}/members endpoint.

As opposed to members, this function returns all the pages of the request at once.

List the members of a group under your account.

Prerequisite: Pro, Business, or Education account
Scopes: group:read:admin

Rate Limit Label: Medium

Add group members.

This function performs a POST to the /groups/{groupId}/members endpoint.

Add members to a group under your account.

Prerequisite: Pro, Business, or Education account
Scopes: group:write:admin

Rate Limit Label: Medium

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.

Delete a group member.

This function performs a DELETE to the /groups/{groupId}/members/{memberId} endpoint.

Delete a member from a group in a Zoom account.

Prerequisite: Pro, Business, or Education account
Scopes: group:write:admin

Rate Limit Label: Light

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.
  • member_id: &str – User’s first name.

Update a group member.

This function performs a PATCH to the /groups/{groupId}/members/{memberId} endpoint.

Use this API to perform either of the following tasks:

  • Remove a group member from one group and move them to a different group.
  • Set a user’s primary group. By default, the primary group is the first group that user is added to.

If a user is a member of multiple groups, you can assign the user a primary group. The user will use the primary group’s settings by default. However, if the user is a member of a group with locked settings, those group settings will remain locked to the user.

Scopes: group:write:admin
Rate Limit Label: Medium

Prerequisites:

  • A Pro or higher account

Parameters:

  • group_id: &str – The group’s unique ID. To get this value, use the List Groups API.
    • To set a user’s primary group, use the target_group_id value for this parameter’s value.
    • To move a group member from one group to another, use the groupId of the designated group.
  • member_id: &str – The group member’s unique ID. To get this value, use the List Group Members API.

Get a group’s settings.

This function performs a GET to the /groups/{groupId}/settings endpoint.

Get settings for a group. Prerequisite: Pro, Business, or Education account
Scopes: group:read:admin

Rate Limit Label: Medium

Parameters:

  • option: crate::types::OptionData – Use the following options to filter the results of the account’s information: * meeting_authentication — View the account’s meeting authentication settings. * recording_authentication — View the account’s recording authentication settings. * security — View the account’s security settings. For example, password requirements for user login or two-factor authentication.
    * meeting_security — View the account’s meeting security settings.

Get a group’s settings.

This function performs a GET to the /groups/{groupId}/settings endpoint.

Get settings for a group. Prerequisite: Pro, Business, or Education account
Scopes: group:read:admin

Rate Limit Label: Medium

Parameters:

  • option: crate::types::OptionData – Use the following options to filter the results of the account’s information: * meeting_authentication — View the account’s meeting authentication settings. * recording_authentication — View the account’s recording authentication settings. * security — View the account’s security settings. For example, password requirements for user login or two-factor authentication.
    * meeting_security — View the account’s meeting security settings.

Get a group’s settings.

This function performs a GET to the /groups/{groupId}/settings endpoint.

Get settings for a group. Prerequisite: Pro, Business, or Education account
Scopes: group:read:admin

Rate Limit Label: Medium

Parameters:

  • option: crate::types::OptionData – Use the following options to filter the results of the account’s information: * meeting_authentication — View the account’s meeting authentication settings. * recording_authentication — View the account’s recording authentication settings. * security — View the account’s security settings. For example, password requirements for user login or two-factor authentication.
    * meeting_security — View the account’s meeting security settings.

Get a group’s settings.

This function performs a GET to the /groups/{groupId}/settings endpoint.

Get settings for a group. Prerequisite: Pro, Business, or Education account
Scopes: group:read:admin

Rate Limit Label: Medium

Parameters:

  • option: crate::types::OptionData – Use the following options to filter the results of the account’s information: * meeting_authentication — View the account’s meeting authentication settings. * recording_authentication — View the account’s recording authentication settings. * security — View the account’s security settings. For example, password requirements for user login or two-factor authentication.
    * meeting_security — View the account’s meeting security settings.

Update a group’s settings.

This function performs a PATCH to the /groups/{groupId}/settings endpoint.

Update settings for a group.


Note: The force_pmi_jbh_password field under meeting settings is planned to be deprecated on September 22, 2019. This field will be replaced by another field that will provide the same functionality.

Prerequisite: Pro, Business, or Education account
Scopes: group:write:admin

Rate Limit Label: Medium

Parameters:

  • group_id: &str – User’s first name.
  • option: crate::types::UpdateGroupSettingsOption

Get locked settings.

This function performs a GET to the /groups/{groupId}/lock_settings endpoint.

Retrieve a group’s locked settings. If you lock a setting, the group members will not be able to modify it individually.


Note: The force_pmi_jbh_password field under meeting settings is planned to be deprecated on September 22, 2019. This field will be replaced by another field that will provide the same functionality.

Prerequisite: Pro, Business, or Education account
Scopes: group:read:admin

Rate Limit Label: Medium

Parameters:

  • group_id: &str – User’s first name.
  • option: &str – Specify meeting_security as the value of this field if you would like to view security settings applied on a meeting hosted by the users in this group.

Get locked settings.

This function performs a GET to the /groups/{groupId}/lock_settings endpoint.

Retrieve a group’s locked settings. If you lock a setting, the group members will not be able to modify it individually.


Note: The force_pmi_jbh_password field under meeting settings is planned to be deprecated on September 22, 2019. This field will be replaced by another field that will provide the same functionality.

Prerequisite: Pro, Business, or Education account
Scopes: group:read:admin

Rate Limit Label: Medium

Parameters:

  • group_id: &str – User’s first name.
  • option: &str – Specify meeting_security as the value of this field if you would like to view security settings applied on a meeting hosted by the users in this group.

Get locked settings.

This function performs a GET to the /groups/{groupId}/lock_settings endpoint.

Retrieve a group’s locked settings. If you lock a setting, the group members will not be able to modify it individually.


Note: The force_pmi_jbh_password field under meeting settings is planned to be deprecated on September 22, 2019. This field will be replaced by another field that will provide the same functionality.

Prerequisite: Pro, Business, or Education account
Scopes: group:read:admin

Rate Limit Label: Medium

Parameters:

  • group_id: &str – User’s first name.
  • option: &str – Specify meeting_security as the value of this field if you would like to view security settings applied on a meeting hosted by the users in this group.

Update locked settings.

This function performs a PATCH to the /groups/{groupId}/lock_settings endpoint.

Update a group’s locked settings. If you lock a setting, the group members will not be able to modify it individually.


Note: The force_pmi_jbh_password field under meeting settings is planned to be deprecated on September 22, 2019. This field will be replaced by another field that will provide the same functionality.

Prerequisite: Pro, Business, or Education account
Scopes: group:write:admin

Rate Limit Label: Medium

Parameters:

  • group_id: &str – User’s first name.
  • option: &str – Specify meeting_security as the value of this field if you would like to view security settings applied on a meeting hosted by the users in this group.

Upload virtual background files.

This function performs a POST to the /groups/{groupId}/settings/virtual_backgrounds endpoint.

Use this API to upload virtual background files for all users in a group to use.

Prerequisites:

`

Parameters:

  • group_id: &str – Unique identifier of the group. Retrieve the value for this field by calling the List groups API.

Delete virtual background files.

This function performs a DELETE to the /groups/{groupId}/settings/virtual_backgrounds endpoint.

Delete existing virtual background file(s) from an account.

Prerequisites:

Parameters:

  • group_id: &str – Unique identifier of the group. Retrieve the value for this field by calling the List groups API.
  • file_ids: &str – Provide the id of the file that is to be deleted. To delete multiple files, provide comma separated values for this field.