pub struct ImGroups {
    pub client: Client,
}

Fields

client: Client

Implementations

List IM directory groups.

This function performs a GET to the /im/groups endpoint.

List IM directory groups.

Scopes: imgroup:read:admin

Rate Limit Label: Medium

Create an IM directory group.

This function performs a POST to the /im/groups endpoint.

Create an IM directory group under your account.

Scopes: imgroup:write:admin

Rate Limit Label: Light

Retrieve an IM directory group.

This function performs a GET to the /im/groups/{groupId} endpoint.

Retrieve an IM directory group under your account.

Scopes: imgroup:read:admin

Rate Limit Label: Light

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.

Delete an IM directory group.

This function performs a DELETE to the /im/groups/{groupId} endpoint.

Delete an IM directory group under your account.

Scopes: imgroup:write:admin

Rate Limit Label: Light

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.

Update an IM directory group.

This function performs a PATCH to the /im/groups/{groupId} endpoint.

Update an IM directory group under your account.

Scopes: imgroup:write:admin

Rate Limit Label: Light

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.

List IM directory group members.

This function performs a GET to the /im/groups/{groupId}/members endpoint.

List the members of an IM directory group.

Scope: imgroup:read:admin

Rate Limit Label: Medium

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.

  • page_size: i64 – The number of records returned within a single API call.

  • page_number: i64Deprecated - This field has been deprecated and we will stop supporting it completely in a future release. Please use “next_page_token” for pagination instead of this field.

    The page number of the current page in the returned records.

  • next_page_token: &str – The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.

Add IM directory group members.

This function performs a POST to the /im/groups/{groupId}/members endpoint.

Add members to an IM directory group under an account.

Scope: imgroup:write:admin

Rate Limit Label: Medium

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.

Delete IM directory group member.

This function performs a DELETE to the /im/groups/{groupId}/members/{memberId} endpoint.

Delete a member from an IM directory group under an account.

Scopes: imgroup:write:admin

Rate Limit Label: Light

Parameters:

  • group_id: &str – The group ID.
    Can be retrieved by calling GET /groups.
  • member_id: &str – User’s first name.