Struct zoom_api::pac::Pac

source ·
pub struct Pac {
    pub client: Client,
}

Fields

client: Client

Implementations

List a user’s PAC accounts.

This function performs a GET to the /users/{userId}/pac endpoint.

Use this API to list a user’s Personal Audio Conference accounts. For user-level apps, pass the me value instead of the userId parameter.

PAC allows Pro or higher account holders to host meetings through PSTN (phone dial-in) only.

Scopes: pac:read:admin, pac:read
Rate Limit Label: Light

Prerequisites:

Parameters:

  • user_id: &str – The user ID or email address of the user. For user-level apps, pass me as the value for userId.