Struct zoom_api::phone_call_queues::PhoneCallQueues
source · pub struct PhoneCallQueues {
pub client: Client,
}Fields
client: ClientImplementations
sourceimpl PhoneCallQueues
impl PhoneCallQueues
sourcepub async fn list_call_queues(
&self,
next_page_token: &str,
page_size: i64
) -> Result<Vec<CallQueues>>
pub async fn list_call_queues(
&self,
next_page_token: &str,
page_size: i64
) -> Result<Vec<CallQueues>>
List call queues.
This function performs a GET to the /phone/call_queues endpoint.
Call queues allow you to route incoming calls to a group of users. For instance, you can use call queues to route calls to various departments in your organization such as sales, engineering, billing, customer service etc.
Use this API to list Call queues.
Prerequisites:
- Pro, Business, or Education account
- Account owner or admin permissions
- Zoom Phone license
Scopes:phone:read:admin
Rate Limit Label: Medium
Parameters:
next_page_token: &str– The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.page_size: i64– The number of records returned from a single API call.
sourcepub async fn list_all_call_queues(&self) -> Result<Vec<CallQueues>>
pub async fn list_all_call_queues(&self) -> Result<Vec<CallQueues>>
List call queues.
This function performs a GET to the /phone/call_queues endpoint.
As opposed to list_call_queues, this function returns all the pages of the request at once.
Call queues allow you to route incoming calls to a group of users. For instance, you can use call queues to route calls to various departments in your organization such as sales, engineering, billing, customer service etc.
Use this API to list Call queues.
Prerequisites:
- Pro, Business, or Education account
- Account owner or admin permissions
- Zoom Phone license
Scopes:phone:read:admin
Rate Limit Label: Medium
sourcepub async fn create_call_queue(
&self,
body: &CreateCallQueueRequest
) -> Result<CreateCallQueueResponse>
pub async fn create_call_queue(
&self,
body: &CreateCallQueueRequest
) -> Result<CreateCallQueueResponse>
Create a call queue.
This function performs a POST to the /phone/call_queues endpoint.
Call queues allow you to route incoming calls to a group of users. For instance, you can use call queues to route calls to various departments in your organization such as sales, engineering, billing, customer service etc.
Use this API to create a call queue.
You can add phone users or common area phones to call queues.
Prerequisites:
- Pro, Business, or Education account
- Account owner or admin permissions
- Zoom Phone license
Scopes:phone:write:admin
Rate Limit Label: Light
sourcepub async fn get_call_queue(
&self,
call_queue_id: &str
) -> Result<GetCallQueueResponse>
pub async fn get_call_queue(
&self,
call_queue_id: &str
) -> Result<GetCallQueueResponse>
Get call queue details.
This function performs a GET to the /phone/call_queues/{callQueueId} endpoint.
Call queues allow you to route incoming calls to a group of users. For instance, you can use call queues to route calls to various departments in your organization such as sales, engineering, billing, customer service etc.
Use this API to get information on a specific Call Queue.
Prerequisites:
- Pro, Business, or Education account
- Account owner or admin permissions
- Zoom Phone license
Scopes:phone:read:admin
Rate Limit Label: Light
Parameters:
call_queue_id: &str– Unique Identifier of the Call Queue. This can be retrieved from List Call Queues API.
sourcepub async fn delete_call_queue(&self, call_queue_id: &str) -> Result<()>
pub async fn delete_call_queue(&self, call_queue_id: &str) -> Result<()>
Delete a call queue.
This function performs a DELETE to the /phone/call_queues/{callQueueId} endpoint.
Call queues allow you to route incoming calls to a group of users. For instance, you can use call queues to route calls to various departments in your organization such as sales, engineering, billing, customer service etc.
Use this API to delete a Call Queue.
Prerequisites:
- Pro, Business, or Education account
- Account owner or admin permissions
- Zoom Phone license
Scopes:phone:write:admin
Rate Limit Label: Light
Parameters:
call_queue_id: &str– Unique Identifier of the call queue.
sourcepub async fn update_call_queue(
&self,
call_queue_id: &str,
body: &UpdateCallQueueRequest
) -> Result<()>
pub async fn update_call_queue(
&self,
call_queue_id: &str,
body: &UpdateCallQueueRequest
) -> Result<()>
Update call queue details.
This function performs a PATCH to the /phone/call_queues/{callQueueId} endpoint.
Call queues allow you to route incoming calls to a group of users. For instance, you can use call queues to route calls to various departments in your organization such as sales, engineering, billing, customer service etc.
Use this API to update information of a specific Call Queue.
Prerequisites:
- Pro, Business, or Education account
- Account owner or admin permissions
- Zoom Phone license
Scopes:phone:write:admin
Rate Limit Label: Light
Parameters:
call_queue_id: &str– Unique Identifier of the Call Queue.
sourcepub async fn assign(
&self,
call_queue_id: &str,
body: &AddByocNumberResponse
) -> Result<Domains>
pub async fn assign(
&self,
call_queue_id: &str,
body: &AddByocNumberResponse
) -> Result<Domains>
Assign numbers to a call queue.
This function performs a POST to the /phone/call_queues/{callQueueId}/phone_numbers endpoint.
After buying phone number(s), you can assign it, allowing callers to directly dial a number to reach a call queue.
Prerequisites:
- Pro or higher account plan.
- Account owner or admin permissions
- Zoom Phone license
Scopes:phone:write:admin
Rate Limit Label:Light
Parameters:
call_queue_id: &str– Unique Identifier of the Call Queue.
sourcepub async fn unassign_phone_num_call_queue(
&self,
call_queue_id: &str
) -> Result<Domains>
pub async fn unassign_phone_num_call_queue(
&self,
call_queue_id: &str
) -> Result<Domains>
Unassign all phone numbers.
This function performs a DELETE to the /phone/call_queues/{callQueueId}/phone_numbers endpoint.
Use this API to unbind all phone numbers that are assigned to a Call Queue After successful unbinding, the numbers will appear in the Unassigned tab.
If you only need to unassign a specific phone number, use the Unassign a Phone Number API instead.
Prerequisites:
- Pro or higher account palan
- Account owner or admin permissions
- Zoom Phone license
Scopes:phone:write:admin
Rate Limit Label:Light
Parameters:
call_queue_id: &str– Unique Identifier of the Call Queue. This can be retrieved from List Call Queues API.
sourcepub async fn un_assign_phone_num_call_queue(
&self,
call_queue_id: &str,
phone_number_id: &str
) -> Result<Domains>
pub async fn un_assign_phone_num_call_queue(
&self,
call_queue_id: &str,
phone_number_id: &str
) -> Result<Domains>
Unassign a phone number.
This function performs a DELETE to the /phone/call_queues/{callQueueId}/phone_numbers/{phoneNumberId} endpoint.
After assigning a phone number, you can unbind it if you don’t want it to be assigned to a Call Queue. Use this API to unbind a phone number from a Call Queue. After successful unbinding, the number will appear in the Unassigned tab.
Prerequisites:
- Pro or higher account palan
- Account owner or admin permissions
- Zoom Phone license
Scopes:phone:write:admin
Rate Limit Label:Light
Parameters:
call_queue_id: &str– Unique Identifier of the Call Queue. This can be retrieved from the List Call Queues API.phone_number_id: &str– Unique Identifier of the Phone Number. .
sourcepub async fn add_members_call_queue(
&self,
call_queue_id: &str,
body: &AddMembersCallQueueRequestData
) -> Result<Domains>
pub async fn add_members_call_queue(
&self,
call_queue_id: &str,
body: &AddMembersCallQueueRequestData
) -> Result<Domains>
Add members to a call queue.
This function performs a POST to the /phone/call_queues/{callQueueId}/members endpoint.
Add phone users and/or common area phones as members to a specific Call Queue.
Prerequisites:
- Pro or higher account plan.
- Zoom Phone license
Scopes:phone:write:admin
Rate Limit Label: Light
Parameters:
call_queue_id: &str– Unique Identifier of the Call Queue.
sourcepub async fn unassign_all_members(&self, call_queue_id: &str) -> Result<()>
pub async fn unassign_all_members(&self, call_queue_id: &str) -> Result<()>
Unassign all members.
This function performs a DELETE to the /phone/call_queues/{callQueueId}/members endpoint.
Use this API to remove all members from a Call Queue who were previously assigned to that Call Queue. The members could be phone users or common area phones.
Prerequisites:
- Pro or higher account plan.
- Zoom Phone license
Scopes:phone:write:admin
Rate Limit Label: Light
Parameters:
call_queue_id: &str– User’s first name.
sourcepub async fn unassign_member_from_call_queue(
&self,
call_queue_id: &str,
member_id: &str
) -> Result<()>
pub async fn unassign_member_from_call_queue(
&self,
call_queue_id: &str,
member_id: &str
) -> Result<()>
Unassign a member.
This function performs a DELETE to the /phone/call_queues/{callQueueId}/members/{memberId} endpoint.
Use this API to remove a member from a Call Queue who was previously added to that Call Queue. The member could be a phone user or a common area phone. A member who is a Call Queue Manager cannot be unassigned from the Call Queue using this API.
Prerequisites:
- Pro or higher account plan.
- Zoom Phone license
Scopes:phone:write:admin
Rate Limit Label:Light
Parameters:
call_queue_id: &str– Unique Identifier of the Call Queue from which the member needs to be unassigned.member_id: &str– Unique Identifier of the member who needs to be unassigned.
sourcepub async fn change_call_queue_manager(
&self,
call_queue_id: &str,
body: &ChangeCallQueueManagerRequest
) -> Result<()>
pub async fn change_call_queue_manager(
&self,
call_queue_id: &str,
body: &ChangeCallQueueManagerRequest
) -> Result<()>
Change call queue manager.
This function performs a PUT to the /phone/call_queues/{callQueueId}/manager endpoint.
A call queue manager has the privileges to maanage the call queue’s voicemail inbox and recordings, change all call queue settings and call queue policy settings.
Use this API to to set another phone user as the call queue manager.
Prerequisites:
- Pro or higher account plan.
- Account owner or admin permissions
- Zoom Phone license
Scopes:phone:write:admin
Rate Limit Label: Light
Parameters:
call_queue_id: &str– Unique Identifier of the Call Queue.
sourcepub async fn get_call_queue_recordings(
&self,
call_queue_id: &str,
page_size: i64,
next_page_token: &str,
from: NaiveDate,
to: NaiveDate
) -> Result<Vec<GetCallQueueRecordingsResponse>>
pub async fn get_call_queue_recordings(
&self,
call_queue_id: &str,
page_size: i64,
next_page_token: &str,
from: NaiveDate,
to: NaiveDate
) -> Result<Vec<GetCallQueueRecordingsResponse>>
Get call queue recordings.
This function performs a GET to the /phone/call_queues/{callQueueId}/recordings endpoint.
Use this API to view call recordings from the call queue.
Prerequisites:
- Pro or higher account with Zoom Phone license.
- Automatic call recordings must be enabled in the Policy Settings for call queues.
Scope:phone:read:admin
Rate Limit Label:Medium
Parameters:
call_queue_id: &str– Unique Identifier of the Call Queue.page_size: i64– The number of records returned within a single API call.next_page_token: &str– The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.from: chrono::NaiveDate– Start date (within a 6 month range).to: chrono::NaiveDate– End date (within a 6 month range).
sourcepub async fn get_all_call_queue_recordings(
&self,
call_queue_id: &str,
from: NaiveDate,
to: NaiveDate
) -> Result<Vec<GetCallQueueRecordingsResponse>>
pub async fn get_all_call_queue_recordings(
&self,
call_queue_id: &str,
from: NaiveDate,
to: NaiveDate
) -> Result<Vec<GetCallQueueRecordingsResponse>>
Get call queue recordings.
This function performs a GET to the /phone/call_queues/{callQueueId}/recordings endpoint.
As opposed to get_call_queue_recordings, this function returns all the pages of the request at once.
Use this API to view call recordings from the call queue.
Prerequisites:
- Pro or higher account with Zoom Phone license.
- Automatic call recordings must be enabled in the Policy Settings for call queues.
Scope:phone:read:admin
Rate Limit Label:Medium