PhoneReports

Struct PhoneReports 

pub struct PhoneReports {
    pub client: Client,
}

Fields

client: Client

Implementations

Source

impl PhoneReports

pub async fn get_ps_operation_log( &self, from: &str, to: &str, category_type: &str, page_size: i64, next_page_token: &str, ) -> Result<Response<ReportOperationLogsResponseAllOf>, ClientError>

Get operation logs report.

This function performs a GET to the /phone/reports/operationlogs endpoint.

The Phone System operation logs report allows account owners and admins to view monthly Zoom phone related admin operation details.

Use this API to retrieve the Phone System Operation Logs Report. Account owners and admins can also access this information by logging into their Zoom accounts and navigating to Phone System Operation Logs.

Scopes: phone:read:admin, phone:write:admin
Rate Limit Label: Heavy

Prerequisites:

  • Account must be enrollled in Pro or a higher plan
  • Account must be enrolled in a Zoom Phone plan

Parameters:

  • from: &str – Start date in ‘yyyy-mm-dd’ format. The date range defined by the “from” and “to” parameters should only be one month as the report provides only one month worth of data per API request.
  • to: &str – End date in ‘yyyy-mm-dd’ format.
  • category_type: &str – Filter the response by the category of the action performed. By default, the value of this field is “all” and thus, the response will include log of all operations for the defined period.

    To only include response for a specific category type, provide a value for category_type from this table.
  • page_size: i64 – The number of records returned within a single API call.
  • next_page_token: &str – The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.