pub enum AccountPlanAddonCreateRequestOneOf {
PlanBase(PlanBase),
AccountPlanAddonCreateRequest(AccountPlanAddonCreateRequest),
}Expand description
All of the following types:
PlanBaseAccountPlanAddonCreateRequest
You can easily convert this enum to the inner value with From and Into, as both are implemented for each type.
Variants
PlanBase(PlanBase)
Account base plan object.
AccountPlanAddonCreateRequest(AccountPlanAddonCreateRequest)
Zoom Phone Plan Object
Implementations
sourceimpl AccountPlanAddonCreateRequestOneOf
impl AccountPlanAddonCreateRequestOneOf
pub fn account_plan_addon_create_request(
&self
) -> Option<&AccountPlanAddonCreateRequest>
pub fn plan_base(&self) -> Option<&PlanBase>