pub enum AccountSettingsResponseOneOf {
Domains(Domains),
Security(Security),
AccountSettings(AccountSettings),
MeetingSecuritySettings(MeetingSecuritySettings),
}Expand description
All of the following types:
DomainsSecurityAccountSettingsMeetingSecuritySettings
You can easily convert this enum to the inner value with From and Into, as both are implemented for each type.
Variants
Domains(Domains)
Security(Security)
Security settings of an Account.
AccountSettings(AccountSettings)
MeetingSecuritySettings(MeetingSecuritySettings)
Implementations
sourceimpl AccountSettingsResponseOneOf
impl AccountSettingsResponseOneOf
pub fn account_settings(&self) -> Option<&AccountSettings>
pub fn domains(&self) -> Option<&Domains>
pub fn meeting_security_settings(&self) -> Option<&MeetingSecuritySettings>
pub fn security(&self) -> Option<&Security>