pub enum AccountSettingsUpdateRequestOneOf {
Domains(Domains),
UpdateAccountSettings(UpdateAccountSettings),
MeetingSecuritySettings(MeetingSecuritySettings),
}Expand description
All of the following types:
DomainsUpdateAccountSettingsMeetingSecuritySettings
You can easily convert this enum to the inner value with From and Into, as both are implemented for each type.
Variants
Domains(Domains)
UpdateAccountSettings(UpdateAccountSettings)
MeetingSecuritySettings(MeetingSecuritySettings)
Implementations
sourceimpl AccountSettingsUpdateRequestOneOf
impl AccountSettingsUpdateRequestOneOf
pub fn domains(&self) -> Option<&Domains>
pub fn meeting_security_settings(&self) -> Option<&MeetingSecuritySettings>
pub fn update_account_settings(&self) -> Option<&UpdateAccountSettings>