Enum zoom_api::types::AnswerQuestions
source · pub enum AnswerQuestions {
All,
Only,
Noop,
FallthroughString,
}Expand description
Indicate whether you want attendees to be able to view answered questions only or view all questions.
-
only: Attendees are able to view answered questions only. -
all: Attendees are able to view all questions submitted in the Q&A.
Variants
All
Only
Noop
FallthroughString
Implementations