pub enum DashboardMeetingParticipantsIncludeFields {
RegistrantId,
Noop,
FallthroughString,
}Expand description
Provide registrant_id as the value for this field if you would like to see the registrant ID attribute in the response of this API call. A registrant ID is a unique identifier of a meeting registrant. This is not supported for live meeting types.
Variants
Implementations