pub enum DashboardMeetingParticipantsResponseDevice {
Android,
H323Sip,
Mac,
Phone,
Windows,
IOs,
Noop,
FallthroughString,
}Expand description
The type of device the participant used to join the meeting:
Phone— Participant joined via PSTN.H.323/SIP— Participant joined via an H.323 or SIP device.Windows— Participant joined via VoIP using a Windows device.Mac— Participant joined via VoIP using a Mac device.iOS— Participant joined via VoIP using an iOS device.Android— Participant joined via VoIP using an Android device.
Note: This response returns an empty string (““) value for any users who are not a part of the host’s account (external users).
Variants
Android
H323Sip
Mac
Phone
Windows
IOs
Noop
FallthroughString
Implementations