Enum zoom_api::types::DashboardMeetingsType
source · pub enum DashboardMeetingsType {
Live,
Past,
PastOne,
FallthroughString,
}Expand description
Specify a value to get the response for the corresponding meeting type. The value of this field can be one of the following:
past - Meeting that already occurred in the specified date range.pastOne - Past meetings that were attended by only one user. live - Live meetings.
If you do not provide this field, the default value will be live and thus, the API will only query responses for live meetings.
Variants
Live
Past
PastOne
FallthroughString