Enum zoom_api::types::DeviceType
source · pub enum DeviceType {
CompanionWhiteboard,
Controller,
SchedulingDisplay,
ZoomRoomsComputer,
ZoomRoomsControlSystem,
Noop,
FallthroughString,
}Expand description
Type of the device. The value of this field can be one of the following:Zoom Rooms Computer,
Controller, Scheduling Display, Zoom Rooms Control System, Companion Whiteboard
Variants
CompanionWhiteboard
Controller
SchedulingDisplay
ZoomRoomsComputer
ZoomRoomsControlSystem
Noop
FallthroughString
Implementations
sourceimpl DeviceType
impl DeviceType