Enum zoom_api::types::EncryptionType
source · pub enum EncryptionType {
E2Ee,
EnhancedEncryption,
Noop,
FallthroughString,
}Expand description
Choose between enhanced encryption and end-to-end encryption when starting or a meeting. When using end-to-end encryption, several features (e.g. cloud recording, phone/SIP/H.323 dial-in) will be automatically disabled.
The value of this field can be one of the following:
enhanced_encryption: Enhanced encryption. Encryption is stored in the cloud if you enable this option.
e2ee: End-to-end encryption. The encryption key is stored in your local device and can not be obtained by anyone else. Enabling this setting also disables the following features: join before host, cloud recording, streaming, live transcription, breakout rooms, polling, 1:1 private chat, and meeting reactions.
Variants
E2Ee
EnhancedEncryption
Noop
FallthroughString
Implementations
sourceimpl EncryptionType
impl EncryptionType