pub enum FileType {
Cc,
Chat,
Csv,
M4A,
Mp4,
Transcript,
Noop,
FallthroughString,
}Expand description
The archived file’s file type:
MP4— Video file.M4A— Audio-only file.TRANSCRIPT— A transcript file of the recording, in VTT file format.CHAT— A TXT file containing chat messages that were sent during the meeting.CC— A file containing the recording’s closed captions, in VTT file format.CSV— A file containing polling data in, in CSV format.
For more information, read our Managing and sharing cloud recordings documentation.
Variants
Cc
Chat
Csv
M4A
Mp4
Transcript
Noop
FallthroughString
Implementations