pub enum GetChatMessagesResponseStatus {
Deleted,
Edited,
Normal,
Noop,
FallthroughString,
}Expand description
This field indicates whether a message is an original message(unedited), an edited message or a deleted message.
This field is only returned if you set the value of for include_deleted_and_edited_message query parameter to true.
Variants
Deleted
Edited
Normal
Noop
FallthroughString
Implementations