pub enum GetGroupLockSettingsResponseOneOf {
MeetingSecuritySettings(MeetingSecuritySettings),
GetGroupLockSettingsResponse(GetGroupLockSettingsResponse),
}Expand description
All of the following types:
MeetingSecuritySettingsGetGroupLockSettingsResponse
You can easily convert this enum to the inner value with From and Into, as both are implemented for each type.
Variants
MeetingSecuritySettings(MeetingSecuritySettings)
GetGroupLockSettingsResponse(GetGroupLockSettingsResponse)
Implementations
sourceimpl GetGroupLockSettingsResponseOneOf
impl GetGroupLockSettingsResponseOneOf
pub fn get_group_lock_settings_response(
&self
) -> Option<&GetGroupLockSettingsResponse>
pub fn meeting_security_settings(&self) -> Option<&MeetingSecuritySettings>