pub enum GetGroupSettingsResponseOneOf {
Domains(Domains),
MeetingSecuritySettings(MeetingSecuritySettings),
GetGroupSettingsResponse(GetGroupSettingsResponse),
}Expand description
All of the following types:
DomainsMeetingSecuritySettingsGetGroupSettingsResponse
You can easily convert this enum to the inner value with From and Into, as both are implemented for each type.
Variants
Domains(Domains)
MeetingSecuritySettings(MeetingSecuritySettings)
GetGroupSettingsResponse(GetGroupSettingsResponse)
Implementations
sourceimpl GetGroupSettingsResponseOneOf
impl GetGroupSettingsResponseOneOf
pub fn domains(&self) -> Option<&Domains>
pub fn get_group_settings_response(&self) -> Option<&GetGroupSettingsResponse>
pub fn meeting_security_settings(&self) -> Option<&MeetingSecuritySettings>