pub enum HoldMusic {
Default,
Disable,
Noop,
FallthroughString,
}Expand description
The value of this field can be either default or disable.
-
default: This means that the hold music can be set using the audio library. -
disable: This means that the hold music is disabled.
Variants
Default
Disable
Noop
FallthroughString
Implementations