Enum zoom_api::types::ImGroupCreateRequestType
source · pub enum ImGroupCreateRequestType {
Normal,
Restricted,
Shared,
FallthroughString,
}Expand description
IM Group types:normal - Only members can see automatically see the other members of this group. Other people can search for members within this group. shared - Everyone under an account can see the group members automatically.restricted - Nobody can see the group or search for members except the members in the group.
Variants
Normal
Restricted
Shared
FallthroughString