pub enum Level {
Manager,
User,
Noop,
FallthroughString,
}Expand description
Level of the user. The value can be one of the following:
manager: A call queue manager has the privilege to change call queue settings, policy settings and manage recordings and voicemail inbox. There can only be one manager for each call queue.
user: Regular user without the privileges of a manager.
Variants
Manager
User
Noop
FallthroughString
Implementations