Enum zoom_api::types::ListPhoneDevicesType
source · pub enum ListPhoneDevicesType {
Assigned,
Unassigned,
Noop,
FallthroughString,
}Expand description
State of the device. The value should be either assigned to list devices that have been assigned to user(s) or unassigned to list devices that have not yet been assigned to any user in the Zoom account.
Variants
Assigned
Unassigned
Noop
FallthroughString
Implementations