pub enum MatchType {
PhoneNumber,
Prefix,
Noop,
FallthroughString,
}Expand description
Indicates the match type for the blocked list. The values can be one of the following:
phoneNumber: Indicates that only a specific phone number that is shown in the phone_number field is blocked.
prefix: Indicates that all numbers starting with prefix that is shown in the phone_number field are blocked.
Variants
PhoneNumber
Prefix
Noop
FallthroughString
Implementations