pub enum Method {
Approve,
Deny,
Noop,
FallthroughString,
}Expand description
Specify whether to allow users from specific regions to join this meeting; or block users from specific regions from joining this meeting.
approve: Allow users from specific regions/countries to join this meeting. If this setting is selected, the approved regions/countries must be included in the approved_list.
deny: Block users from specific regions/countries from joining this meeting. If this setting is selected, the approved regions/countries must be included in the denied_list
Variants
Approve
Deny
Noop
FallthroughString
Implementations