Enum zoom_api::types::OptionData
source · pub enum OptionData {
MeetingAuthentication,
RecordingAuthentication,
Noop,
FallthroughString,
}Expand description
Use the following options to filter the results of the account’s information:
meeting_authentication— View the account’s meeting authentication settings.recording_authentication— View the account’s recording authentication settings.security— View the account’s security settings. For example, password requirements for user login or two-factor authentication.meeting_security— View the account’s meeting security settings.
Variants
MeetingAuthentication
RecordingAuthentication
Noop
FallthroughString
Implementations
sourceimpl OptionData
impl OptionData