Enum zoom_api::types::SettingType
source · pub enum SettingType {
Alert,
Meeting,
FallthroughString,
}Expand description
The type of setting that you would like to retrieve.
alert: Alert Settings applied on the Zoom Rooms Account.
meeting: Meeting settings of the Zoom Rooms Account.
signage: View digital signage settings of the Zoom Rooms Account.
Variants
Alert
Meeting
FallthroughString