Enum zoom_api::types::SignInWithTwoFactorAuth
source · pub enum SignInWithTwoFactorAuth {
All,
Group,
None,
Role,
Noop,
FallthroughString,
}Expand description
Settings for 2FA( two factor authentication ). The value can be one of the following:
all: Two factor authentication will be enabled for all users in the account.
none: Two factor authentication is disabled.
group: Two factor authentication will be enabled for users belonging to specific groups. If 2FA is enabled for certain groups, the group IDs of the group(s) will be provided in the sign_in_with_two_factor_auth_groups field.
role: Two factor authentication will be enabled only for users assigned with specific roles in the account. If 2FA is enabled for specific roles, the role IDs will be provided in the
sign_in_with_two_factor_auth_roles field.
Variants
All
Group
None
Role
Noop
FallthroughString
Implementations