Enum zoom_api::types::WeeklyDays
source · pub enum WeeklyDays {
One,
Two,
Three,
Four,
Five,
Six,
Seven,
FallthroughString,
}Expand description
This field is required if you’re scheduling a recurring meeting of type 2 to state which day(s) of the week the meeting should repeat.
The value for this field could be a number between 1 to 7 in string format. For instance, if the meeting should recur on Sunday, provide "1" as the value of this field.
Note: If you would like the meeting to occur on multiple days of a week, you should provide comma separated values for this field. For instance, if the meeting should recur on Sundays and Tuesdays provide "1,3" as the value of this field.
1 - Sunday. 2 - Monday.3 - Tuesday.4 - Wednesday.5 - Thursday.6 - Friday.7 - Saturday.
Variants
One
Two
Three
Four
Five
Six
Seven
FallthroughString