Enum zoom_api::types::WhoCanShareScreen
source · pub enum WhoCanShareScreen {
All,
Host,
Noop,
FallthroughString,
}Expand description
Indicates who can share their screen or content during meetings. The value can be one of the following:
host: Only host can share the screen.
all: Both hosts and attendees can share their screen during meetings. For Webinar, the hosts and panelists can start screen sharing, but not the attendees.
Variants
All
Host
Noop
FallthroughString
Implementations