Struct zoom_api::types::AccountCreateRequest
source · pub struct AccountCreateRequest {
pub account_name: String,
pub email: String,
pub first_name: String,
pub last_name: String,
pub options: Option<Options>,
pub password: String,
}Expand description
The account object represents an account on Zoom. The account owner is the user who created the account or had an account created for them. You can read more about the Zoom account structure here.
Fields
account_name: StringThe account object represents an account on Zoom. The account owner is the user who created the account or had an account created for them. You can read more about the Zoom account structure here.
email: StringUser’s first name.
first_name: StringUser’s first name.
last_name: StringUser’s first name.
options: Option<Options>The account object represents an account on Zoom. The account owner is the user who created the account or had an account created for them. You can read more about the Zoom account structure here.
password: StringUser’s first name.