Struct zoom_api::types::AccountPlanCreateRequestAllOf
source · pub struct AccountPlanCreateRequestAllOf {
pub account_plans: AccountPlans,
pub account_plan_create_request: AccountPlanCreateRequest,
}Expand description
All of the following types are flattened into one object:
AccountPlansAccountPlanCreateRequest
Fields
account_plans: AccountPlansAccount Plans object.
account_plan_create_request: AccountPlanCreateRequestTrait Implementations
sourceimpl Clone for AccountPlanCreateRequestAllOf
impl Clone for AccountPlanCreateRequestAllOf
sourcefn clone(&self) -> AccountPlanCreateRequestAllOf
fn clone(&self) -> AccountPlanCreateRequestAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AccountPlanCreateRequestAllOf
impl Debug for AccountPlanCreateRequestAllOf
sourceimpl<'de> Deserialize<'de> for AccountPlanCreateRequestAllOf
impl<'de> Deserialize<'de> for AccountPlanCreateRequestAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for AccountPlanCreateRequestAllOf
impl JsonSchema for AccountPlanCreateRequestAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<AccountPlanCreateRequestAllOf> for AccountPlanCreateRequestAllOf
impl PartialEq<AccountPlanCreateRequestAllOf> for AccountPlanCreateRequestAllOf
sourcefn eq(&self, other: &AccountPlanCreateRequestAllOf) -> bool
fn eq(&self, other: &AccountPlanCreateRequestAllOf) -> bool
impl StructuralPartialEq for AccountPlanCreateRequestAllOf