Struct zoom_api::types::AddBatchRegistrantsRequest
source · pub struct AddBatchRegistrantsRequest {
pub auto_approve: Option<bool>,
pub registrants: Vec<AddBatchWebinarRegistrantsRequest>,
}Fields
auto_approve: Option<bool>Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
registrants: Vec<AddBatchWebinarRegistrantsRequest>Trait Implementations
sourceimpl Clone for AddBatchRegistrantsRequest
impl Clone for AddBatchRegistrantsRequest
sourcefn clone(&self) -> AddBatchRegistrantsRequest
fn clone(&self) -> AddBatchRegistrantsRequest
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AddBatchRegistrantsRequest
impl Debug for AddBatchRegistrantsRequest
sourceimpl<'de> Deserialize<'de> for AddBatchRegistrantsRequest
impl<'de> Deserialize<'de> for AddBatchRegistrantsRequest
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for AddBatchRegistrantsRequest
impl JsonSchema for AddBatchRegistrantsRequest
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<AddBatchRegistrantsRequest> for AddBatchRegistrantsRequest
impl PartialEq<AddBatchRegistrantsRequest> for AddBatchRegistrantsRequest
sourcefn eq(&self, other: &AddBatchRegistrantsRequest) -> bool
fn eq(&self, other: &AddBatchRegistrantsRequest) -> bool
impl StructuralPartialEq for AddBatchRegistrantsRequest