Struct zoom_api::types::AddInternalNumbersResponse
source · pub struct AddInternalNumbersResponse {
pub allow_for_external_meetings: bool,
pub allow_join: bool,
pub country: String,
pub display_number: String,
pub id: String,
pub labels: String,
pub languages: Languages,
pub number: String,
pub type_: i64,
pub visible: bool,
}Fields
allow_for_external_meetings: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
allow_join: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
country: StringUser’s first name.
display_number: StringUser’s first name.
id: StringUser’s first name.
labels: StringUser’s first name.
languages: LanguagesSpecify the language in which this phone number should be displayed. Currently, the only supported languages are en-GB, en-US, de-DE.
number: StringUser’s first name.
type_: i64Account seats.
visible: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.