Archiving solution settings. This setting can only be used if you have been granted with archiving solution access by the Zoom support team.
Fields
enable: boolArchiving solution settings. This setting can only be used if you have been granted with archiving solution access by the Zoom support team.
settings: Option<Settings>Archiving solution settings. This setting can only be used if you have been granted with archiving solution access by the Zoom support team.
type_: i64Archiving solution settings. This setting can only be used if you have been granted with archiving solution access by the Zoom support team.