Struct zoom_api::types::ArchiveFiles
source · pub struct ArchiveFiles {
pub download_url: String,
pub file_extension: String,
pub file_size: i64,
pub file_type: FileType,
pub id: String,
pub recording_type: RecordingType,
pub status: String,
}Fields
download_url: StringUser’s first name.
file_extension: StringUser’s first name.
file_size: i64Account seats.
file_type: FileTypeThe archived file’s file type:
* MP4 — Video file.
* M4A — Audio-only file.
* TRANSCRIPT — A transcript file of the recording, in VTT file format.
* CHAT — A TXT file containing chat messages that were sent during the meeting.
* CC — A file containing the recording’s closed captions, in VTT file format.
* CSV — A file containing polling data in, in CSV format.
For more information, read our Managing and sharing cloud recordings documentation.
id: StringUser’s first name.
recording_type: RecordingTypeThe archived file’s recording type:
* shared_screen_with_speaker_view(CC)
* shared_screen_with_speaker_view
* shared_screen_with_gallery_view
* speaker_view
* gallery_view
* shared_screen
* audio_only
* audio_transcript
* chat_file
* active_speaker
* host_video
For more information, read our Managing and sharing cloud recordings documentation.
status: StringUser’s first name.