Struct zoom_api::types::AsDeviceFromCrc
source · pub struct AsDeviceFromCrc {
pub avg_loss: String,
pub bitrate: String,
pub jitter: String,
pub latency: String,
pub max_loss: String,
}Expand description
QoS metrics on screen shares by a participant who joined the meeting via a Cloud Room Connector.
Fields
avg_loss: StringQoS metrics on screen shares by a participant who joined the meeting via a Cloud Room Connector.
bitrate: StringQoS metrics on screen shares by a participant who joined the meeting via a Cloud Room Connector.
jitter: StringQoS metrics on screen shares by a participant who joined the meeting via a Cloud Room Connector.
latency: StringQoS metrics on screen shares by a participant who joined the meeting via a Cloud Room Connector.
max_loss: StringQoS metrics on screen shares by a participant who joined the meeting via a Cloud Room Connector.