Struct zoom_api::types::AuthenticationOption
source · pub struct AuthenticationOption {
pub action: Option<AccountSettingsRecordingAuthenticationUpdateOptionAction>,
pub default_option: bool,
pub domains: String,
pub id: String,
pub name: String,
pub type_: Option<AccountSettingsRecordingAuthenticationUpdateOptionType>,
}Fields
action: Option<AccountSettingsRecordingAuthenticationUpdateOptionAction>default_option: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
domains: StringUser’s first name.
id: StringUser’s first name.
name: StringUser’s first name.
type_: Option<AccountSettingsRecordingAuthenticationUpdateOptionType>Trait Implementations
sourceimpl Clone for AuthenticationOption
impl Clone for AuthenticationOption
sourcefn clone(&self) -> AuthenticationOption
fn clone(&self) -> AuthenticationOption
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AuthenticationOption
impl Debug for AuthenticationOption
sourceimpl<'de> Deserialize<'de> for AuthenticationOption
impl<'de> Deserialize<'de> for AuthenticationOption
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for AuthenticationOption
impl JsonSchema for AuthenticationOption
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<AuthenticationOption> for AuthenticationOption
impl PartialEq<AuthenticationOption> for AuthenticationOption
sourcefn eq(&self, other: &AuthenticationOption) -> bool
fn eq(&self, other: &AuthenticationOption) -> bool
sourceimpl Serialize for AuthenticationOption
impl Serialize for AuthenticationOption
impl StructuralPartialEq for AuthenticationOption