Struct zoom_api::types::BusinessHours
source · pub struct BusinessHours {
pub business_hour_action: i64,
pub connect_to_operator: Option<ConnectOperator>,
pub custom_hours: Vec<CustomHours>,
pub ring_type: Option<Value>,
pub ringing_duration: Option<Value>,
pub type_: i64,
}Fields
business_hour_action: i64Account seats.
connect_to_operator: Option<ConnectOperator>Allow callers to press Zero to reach an operator or press One to leave a message, or allow neither of these options.
custom_hours: Vec<CustomHours>ring_type: Option<Value>Audio types:1 - Toll-free Call-in & Call-out.2 - Toll
3 - SIP Connected Audio
ringing_duration: Option<Value>Audio types:1 - Toll-free Call-in & Call-out.2 - Toll
3 - SIP Connected Audio
type_: i64Account seats.