Struct zoom_api::types::CallLogs

source ·
pub struct CallLogs {
Show 28 fields pub accepted_by: Option<AcceptedBy>, pub answer_start_time: String, pub call_end_time: String, pub call_id: String, pub callee_name: String, pub callee_number: String, pub callee_number_type: Option<Value>, pub caller_name: String, pub caller_number: String, pub caller_number_type: String, pub charge: String, pub client_code: String, pub date_time: Option<NaiveDate>, pub direction: String, pub duration: i64, pub forwarded_by: Option<ForwardedBy>, pub forwarded_to: Option<ForwardedTo>, pub has_recording: bool, pub has_voicemail: bool, pub id: String, pub outgoing_by: Option<OutgoingBy>, pub path: String, pub rate: String, pub recording_type: String, pub result: String, pub site: Option<Site>, pub user_id: String, pub waiting_time: i64,
}

Fields

accepted_by: Option<AcceptedBy>

Indicates who accepted the call.

answer_start_time: String

User’s first name.

call_end_time: String

User’s first name.

call_id: String

User’s first name.

callee_name: String

User’s first name.

callee_number: String

User’s first name.

callee_number_type: Option<Value>

Audio types:
1 - Toll-free Call-in & Call-out.
2 - Toll
3 - SIP Connected Audio

caller_name: String

User’s first name.

caller_number: String

User’s first name.

caller_number_type: String

User’s first name.

charge: String

User’s first name.

client_code: String

User’s first name.

date_time: Option<NaiveDate>

Start Date.

direction: String

User’s first name.

duration: i64

Account seats.

forwarded_by: Option<ForwardedBy>

Indicates where the call was forwarded from.

forwarded_to: Option<ForwardedTo>

Indicates who the call was forwarded to.

has_recording: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

has_voicemail: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

id: String

User’s first name.

outgoing_by: Option<OutgoingBy>path: String

User’s first name.

rate: String

User’s first name.

recording_type: String

User’s first name.

result: String

User’s first name.

site: Option<Site>user_id: String

User’s first name.

waiting_time: i64

Account seats.