pub struct CallerQos {
pub device_private_ip: String,
pub device_public_ip: String,
pub receiving: Vec<Sending>,
pub sending: Vec<Sending>,
}Expand description
Quality of Service object that represents the call quality data of the caller.
Fields
device_private_ip: StringQuality of Service object that represents the call quality data of the caller.
device_public_ip: StringQuality of Service object that represents the call quality data of the caller.
receiving: Vec<Sending>Quality of Service object that represents the call quality data of the caller.
sending: Vec<Sending>Quality of Service object that represents the call quality data of the caller.