Struct zoom_api::types::ChannelSettings
source · pub struct ChannelSettings {
pub allow_to_add_external_users: i64,
pub new_members_can_see_previous_messages_files: bool,
pub posting_permissions: i64,
}Fields
allow_to_add_external_users: i64Account seats.
new_members_can_see_previous_messages_files: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
posting_permissions: i64Account seats.