Struct zoom_api::types::CloseHours
source · pub struct CloseHours {
pub close_hour_action: i64,
pub connect_to_operator: Option<ConnectOperator>,
pub max_wait_time: Option<Value>,
}Fields
close_hour_action: i64Account seats.
connect_to_operator: Option<ConnectOperator>Allow callers to press Zero to reach an operator or press One to leave a message, or allow neither of these options.
max_wait_time: Option<Value>Audio types:1 - Toll-free Call-in & Call-out.2 - Toll
3 - SIP Connected Audio