Struct zoom_api::types::ConnectOperator
source · pub struct ConnectOperator {
pub enable: bool,
pub id: String,
pub type_: Option<GetSettingTemplateResponseUserSettingsCallHandlingBusinessHoursConnectOperatorType>,
}Expand description
Allow callers to press Zero to reach an operator or press One to leave a message, or allow neither of these options.
Fields
enable: boolAllow callers to press Zero to reach an operator or press One to leave a message, or allow neither of these options.
id: StringAllow callers to press Zero to reach an operator or press One to leave a message, or allow neither of these options.
type_: Option<GetSettingTemplateResponseUserSettingsCallHandlingBusinessHoursConnectOperatorType>Allow callers to press Zero to reach an operator or press One to leave a message, or allow neither of these options.