Struct zoom_api::types::CreateRoleRequest
source · pub struct CreateRoleRequest {
pub description: String,
pub name: String,
pub privileges: Vec<String>,
}Fields
description: StringUser’s first name.
name: StringUser’s first name.
privileges: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.