Struct zoom_api::types::CustomQuestions
source · pub struct CustomQuestions {
pub answers: Vec<String>,
pub required: bool,
pub title: String,
pub type_: Option<MeetingRegistrantQuestionsCustomType>,
}Fields
answers: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.
required: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
title: StringUser’s first name.
type_: Option<MeetingRegistrantQuestionsCustomType>Type of the question being asked.