Struct zoom_api::types::DashboardChatResponseAllOf
source · pub struct DashboardChatResponseAllOf {
pub dashboard_chat_response: DashboardChatResponse,
pub dashboard_chat_response_data: DashboardChatResponseData,
}Expand description
All of the following types are flattened into one object:
DashboardChatResponseDashboardChatResponseData
Fields
dashboard_chat_response: DashboardChatResponsedashboard_chat_response_data: DashboardChatResponseDataTrait Implementations
sourceimpl Clone for DashboardChatResponseAllOf
impl Clone for DashboardChatResponseAllOf
sourcefn clone(&self) -> DashboardChatResponseAllOf
fn clone(&self) -> DashboardChatResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for DashboardChatResponseAllOf
impl Debug for DashboardChatResponseAllOf
sourceimpl<'de> Deserialize<'de> for DashboardChatResponseAllOf
impl<'de> Deserialize<'de> for DashboardChatResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for DashboardChatResponseAllOf
impl JsonSchema for DashboardChatResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<DashboardChatResponseAllOf> for DashboardChatResponseAllOf
impl PartialEq<DashboardChatResponseAllOf> for DashboardChatResponseAllOf
sourcefn eq(&self, other: &DashboardChatResponseAllOf) -> bool
fn eq(&self, other: &DashboardChatResponseAllOf) -> bool
impl StructuralPartialEq for DashboardChatResponseAllOf