Struct zoom_api::types::DashboardImResponseAllOf
source · pub struct DashboardImResponseAllOf {
pub pagination_token: PaginationToken,
pub dashboard_im_response: DashboardImResponse,
pub dashboard_im_response_data: DashboardImResponseData,
}Expand description
All of the following types are flattened into one object:
PaginationTokenDashboardImResponseDashboardImResponseData
Fields
pagination_token: PaginationTokenPagination object.
dashboard_im_response: DashboardImResponsedashboard_im_response_data: DashboardImResponseDataTrait Implementations
sourceimpl Clone for DashboardImResponseAllOf
impl Clone for DashboardImResponseAllOf
sourcefn clone(&self) -> DashboardImResponseAllOf
fn clone(&self) -> DashboardImResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for DashboardImResponseAllOf
impl Debug for DashboardImResponseAllOf
sourceimpl<'de> Deserialize<'de> for DashboardImResponseAllOf
impl<'de> Deserialize<'de> for DashboardImResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for DashboardImResponseAllOf
impl JsonSchema for DashboardImResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<DashboardImResponseAllOf> for DashboardImResponseAllOf
impl PartialEq<DashboardImResponseAllOf> for DashboardImResponseAllOf
sourcefn eq(&self, other: &DashboardImResponseAllOf) -> bool
fn eq(&self, other: &DashboardImResponseAllOf) -> bool
sourceimpl Serialize for DashboardImResponseAllOf
impl Serialize for DashboardImResponseAllOf
impl StructuralPartialEq for DashboardImResponseAllOf