pub struct DashboardMeetingParticipantsResponse {Show 32 fields
pub audio_quality: Option<AudioQuality>,
pub camera: String,
pub connection_type: String,
pub customer_key: String,
pub data_center: String,
pub device: Option<DashboardMeetingParticipantsResponseDevice>,
pub domain: String,
pub email: String,
pub harddisk_id: String,
pub id: String,
pub in_room_participants: i64,
pub ip_address: String,
pub join_time: Option<DateTime<Utc>>,
pub leave_reason: String,
pub leave_time: Option<DateTime<Utc>>,
pub location: String,
pub mac_addr: String,
pub microphone: String,
pub network_type: Option<NetworkType>,
pub pc_name: String,
pub recording: bool,
pub registrant_id: String,
pub screen_share_quality: Option<AudioQuality>,
pub share_application: bool,
pub share_desktop: bool,
pub share_whiteboard: bool,
pub speaker: String,
pub status: Option<DashboardMeetingParticipantsResponseStatus>,
pub user_id: String,
pub user_name: String,
pub version: String,
pub video_quality: Option<AudioQuality>,
}Fields
audio_quality: Option<AudioQuality>Audio quality of the participant.
camera: StringUser’s first name.
connection_type: StringUser’s first name.
customer_key: StringUser’s first name.
data_center: StringUser’s first name.
device: Option<DashboardMeetingParticipantsResponseDevice>The type of device the participant used to join the meeting:
* Phone — Participant joined via PSTN.
* H.323/SIP — Participant joined via an H.323 or SIP device.
* Windows — Participant joined via VoIP using a Windows device.
* Mac — Participant joined via VoIP using a Mac device.
* iOS — Participant joined via VoIP using an iOS device.
* Android — Participant joined via VoIP using an Android device.
**Note:** This response returns an empty string (““) value for any users who are **not** a part of the host’s account (external users).
domain: StringUser’s first name.
email: StringUser’s first name.
harddisk_id: StringUser’s first name.
id: StringUser’s first name.
in_room_participants: i64Account seats.
ip_address: StringUser’s first name.
join_time: Option<DateTime<Utc>>Account subscription start date and time.
leave_reason: StringUser’s first name.
leave_time: Option<DateTime<Utc>>Account subscription start date and time.
location: StringUser’s first name.
mac_addr: StringUser’s first name.
microphone: StringUser’s first name.
network_type: Option<NetworkType>The participant’s network type:
* Wired
* Wifi
* PPP — Point-to-Point.
* Cellular — 3G, 4G, and 5G cellular.
* Others — An unknown device.
pc_name: StringUser’s first name.
recording: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
registrant_id: StringUser’s first name.
Audio quality of the participant.
Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
speaker: StringUser’s first name.
status: Option<DashboardMeetingParticipantsResponseStatus>Indicates whether the participant is in the waiting room or in the meeting.
The value of this field can be in_meeting or in_waiting_room.
user_id: StringUser’s first name.
user_name: StringUser’s first name.
version: StringUser’s first name.
video_quality: Option<AudioQuality>Audio quality of the participant.