pub struct DashboardMeetingParticipantsResponseData {
pub participants: Vec<DashboardMeetingParticipantsResponse>,
}Fields
participants: Vec<DashboardMeetingParticipantsResponse>Array of participant session objects. If a participant left a meeting and rejoined the same meeting, their information will appear multiple times (as many times as they joined the meeting).
If the account calling this API is a business associate (BAA) under HIPAA, this array returns an empty string value for the user_name, ip_address, location, and email responses.