Struct zoom_api::types::DashboardMeetingsResponseAllOf
source · pub struct DashboardMeetingsResponseAllOf {
pub pagination_token: PaginationToken,
pub dashboard_im_response: DashboardImResponse,
pub dashboard_meetings_response: DashboardMeetingsResponse,
}Expand description
All of the following types are flattened into one object:
PaginationTokenDashboardImResponseDashboardMeetingsResponse
Fields
pagination_token: PaginationTokenPagination object.
dashboard_im_response: DashboardImResponsedashboard_meetings_response: DashboardMeetingsResponseTrait Implementations
sourceimpl Clone for DashboardMeetingsResponseAllOf
impl Clone for DashboardMeetingsResponseAllOf
sourcefn clone(&self) -> DashboardMeetingsResponseAllOf
fn clone(&self) -> DashboardMeetingsResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for DashboardMeetingsResponseAllOf
impl<'de> Deserialize<'de> for DashboardMeetingsResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for DashboardMeetingsResponseAllOf
impl JsonSchema for DashboardMeetingsResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<DashboardMeetingsResponseAllOf> for DashboardMeetingsResponseAllOf
impl PartialEq<DashboardMeetingsResponseAllOf> for DashboardMeetingsResponseAllOf
sourcefn eq(&self, other: &DashboardMeetingsResponseAllOf) -> bool
fn eq(&self, other: &DashboardMeetingsResponseAllOf) -> bool
impl StructuralPartialEq for DashboardMeetingsResponseAllOf