pub struct DashboardWebinarParticipantsResponseAllOf {
pub pagination_token: PaginationToken,
pub dashboard_webinar_participants_response_data: DashboardWebinarParticipantsResponseData,
}Expand description
All of the following types are flattened into one object:
PaginationTokenDashboardWebinarParticipantsResponseData
Fields
pagination_token: PaginationTokenPagination object.
dashboard_webinar_participants_response_data: DashboardWebinarParticipantsResponseDataTrait Implementations
sourceimpl Clone for DashboardWebinarParticipantsResponseAllOf
impl Clone for DashboardWebinarParticipantsResponseAllOf
sourcefn clone(&self) -> DashboardWebinarParticipantsResponseAllOf
fn clone(&self) -> DashboardWebinarParticipantsResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for DashboardWebinarParticipantsResponseAllOf
impl<'de> Deserialize<'de> for DashboardWebinarParticipantsResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for DashboardWebinarParticipantsResponseAllOf
impl JsonSchema for DashboardWebinarParticipantsResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<DashboardWebinarParticipantsResponseAllOf> for DashboardWebinarParticipantsResponseAllOf
impl PartialEq<DashboardWebinarParticipantsResponseAllOf> for DashboardWebinarParticipantsResponseAllOf
sourcefn eq(&self, other: &DashboardWebinarParticipantsResponseAllOf) -> bool
fn eq(&self, other: &DashboardWebinarParticipantsResponseAllOf) -> bool
impl StructuralPartialEq for DashboardWebinarParticipantsResponseAllOf