Struct zoom_api::types::DashboardWebinarsResponseAllOf
source · pub struct DashboardWebinarsResponseAllOf {
pub pagination_token: PaginationToken,
pub dashboard_im_response: DashboardImResponse,
pub dashboard_webinars_response: DashboardWebinarsResponse,
}Expand description
All of the following types are flattened into one object:
PaginationTokenDashboardImResponseDashboardWebinarsResponse
Fields
pagination_token: PaginationTokenPagination object.
dashboard_im_response: DashboardImResponsedashboard_webinars_response: DashboardWebinarsResponseTrait Implementations
sourceimpl Clone for DashboardWebinarsResponseAllOf
impl Clone for DashboardWebinarsResponseAllOf
sourcefn clone(&self) -> DashboardWebinarsResponseAllOf
fn clone(&self) -> DashboardWebinarsResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for DashboardWebinarsResponseAllOf
impl<'de> Deserialize<'de> for DashboardWebinarsResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for DashboardWebinarsResponseAllOf
impl JsonSchema for DashboardWebinarsResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<DashboardWebinarsResponseAllOf> for DashboardWebinarsResponseAllOf
impl PartialEq<DashboardWebinarsResponseAllOf> for DashboardWebinarsResponseAllOf
sourcefn eq(&self, other: &DashboardWebinarsResponseAllOf) -> bool
fn eq(&self, other: &DashboardWebinarsResponseAllOf) -> bool
impl StructuralPartialEq for DashboardWebinarsResponseAllOf