pub struct DeskPhone {
pub keys_positions: Option<KeysPositions>,
}Expand description
Contains information on phones or devices provisioned for the user.
Fields
keys_positions: Option<KeysPositions>Contains information on phones or devices provisioned for the user.