Struct zoom_api::types::DeviceCreateResponseAllOf
source · Expand description
All of the following types are flattened into one object:
DeviceGroups
Fields
device: DeviceThe H.323/SIP device object.
groups: GroupsTrait Implementations
sourceimpl Clone for DeviceCreateResponseAllOf
impl Clone for DeviceCreateResponseAllOf
sourcefn clone(&self) -> DeviceCreateResponseAllOf
fn clone(&self) -> DeviceCreateResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for DeviceCreateResponseAllOf
impl Debug for DeviceCreateResponseAllOf
sourceimpl<'de> Deserialize<'de> for DeviceCreateResponseAllOf
impl<'de> Deserialize<'de> for DeviceCreateResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for DeviceCreateResponseAllOf
impl JsonSchema for DeviceCreateResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<DeviceCreateResponseAllOf> for DeviceCreateResponseAllOf
impl PartialEq<DeviceCreateResponseAllOf> for DeviceCreateResponseAllOf
sourcefn eq(&self, other: &DeviceCreateResponseAllOf) -> bool
fn eq(&self, other: &DeviceCreateResponseAllOf) -> bool
sourceimpl Serialize for DeviceCreateResponseAllOf
impl Serialize for DeviceCreateResponseAllOf
impl StructuralPartialEq for DeviceCreateResponseAllOf