pub struct Devices {
pub app_version: String,
pub device_system: String,
pub device_type: Option<DeviceType>,
pub id: String,
pub room_name: String,
pub status: Option<ListZrDevicesResponseStatus>,
}Fields
app_version: StringUser’s first name.
device_system: StringUser’s first name.
device_type: Option<DeviceType>Type of the device. The value of this field can be one of the following:Zoom Rooms Computer,
Controller, Scheduling Display, Zoom Rooms Control System, Companion Whiteboard
id: StringUser’s first name.
room_name: StringUser’s first name.
status: Option<ListZrDevicesResponseStatus>Status of the device. The value can be either Online or Offline.