Struct zoom_api::types::ExternalContacts
source · pub struct ExternalContacts {
pub description: String,
pub email: String,
pub extension_number: String,
pub external_contact_id: String,
pub id: String,
pub name: String,
pub phone_numbers: Vec<String>,
}Fields
description: StringUser’s first name.
email: StringUser’s first name.
extension_number: StringUser’s first name.
external_contact_id: StringUser’s first name.
id: StringUser’s first name.
name: StringUser’s first name.
phone_numbers: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.