pub struct Files {
pub id: String,
pub is_default: bool,
pub name: String,
pub size: String,
pub type_: String,
}Fields
id: StringUser’s first name.
is_default: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
name: StringUser’s first name.
size: StringUser’s first name.
type_: StringUser’s first name.