Struct zoom_api::types::GetCallQueueResponseMembersUsers
source · pub struct GetCallQueueResponseMembersUsers {
pub id: String,
pub level: Option<Level>,
pub name: String,
pub receive_call: bool,
}Fields
id: StringUser’s first name.
level: Option<Level>Level of the user. The value can be one of the following:
manager: A call queue manager has the privilege to change call queue settings, policy settings and manage recordings and voicemail inbox. There can only be one manager for each call queue.
user: Regular user without the privileges of a manager.
name: StringUser’s first name.
receive_call: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.