pub struct GetGroupLockSettingsResponseTelephony {
pub telephony_regions: bool,
pub third_party_audio: bool,
}Fields
telephony_regions: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
third_party_audio: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.