pub struct GetGroupSettingsResponseEmailNotification {
pub alternative_host_reminder: bool,
pub cancel_meeting_reminder: bool,
pub cloud_recording_available_reminder: bool,
pub jbh_reminder: bool,
pub schedule_for_host_reminder: bool,
}Fields
alternative_host_reminder: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
cancel_meeting_reminder: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
cloud_recording_available_reminder: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
jbh_reminder: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
schedule_for_host_reminder: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.