pub struct GetGroupSettingsResponseInMeeting {
Show 44 fields pub alert_guest_join: bool, pub allow_show_zoom_windows: bool, pub annotation: bool, pub attendee_on_hold: bool, pub auto_answer: bool, pub auto_saving_chat: bool, pub breakout_room: bool, pub chat: bool, pub closed_caption: bool, pub co_host: bool, pub custom_data_center_regions: bool, pub data_center_regions: Vec<String>, pub e_2e_encryption: bool, pub entry_exit_chime: String, pub far_end_camera_control: bool, pub feedback: bool, pub file_transfer: bool, pub group_hd: bool, pub join_from_desktop: bool, pub join_from_mobile: bool, pub non_verbal_feedback: bool, pub only_host_view_device_list: bool, pub original_audio: bool, pub polling: bool, pub post_meeting_feedback: bool, pub private_chat: bool, pub record_play_own_voice: bool, pub remote_control: bool, pub remote_support: bool, pub request_permission_to_unmute: bool, pub screen_sharing: bool, pub sending_default_email_invites: bool, pub show_a_join_from_your_browser_link: bool, pub show_browser_join_link: bool, pub show_device_list: bool, pub show_meeting_control_toolbar: bool, pub stereo_audio: bool, pub use_html_format_email: bool, pub virtual_background: bool, pub virtual_background_settings: Option<VirtualBackgroundSettings>, pub waiting_room: bool, pub whiteboard: bool, pub who_can_share_screen: Option<WhoCanShareScreen>, pub who_can_share_screen_when_someone_is_sharing: Option<WhoCanShareScreen>,
}

Fields

alert_guest_join: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

allow_show_zoom_windows: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

annotation: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

attendee_on_hold: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

auto_answer: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

auto_saving_chat: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

breakout_room: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

chat: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

closed_caption: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

co_host: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

custom_data_center_regions: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

data_center_regions: Vec<String>

Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.

**Note:** This option can only be used if the value of share_rc is set to true.

e_2e_encryption: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

entry_exit_chime: String

User’s first name.

far_end_camera_control: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

feedback: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

file_transfer: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

group_hd: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

join_from_desktop: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

join_from_mobile: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

non_verbal_feedback: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

only_host_view_device_list: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

original_audio: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

polling: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

post_meeting_feedback: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

private_chat: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

record_play_own_voice: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

remote_control: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

remote_support: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

request_permission_to_unmute: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

screen_sharing: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

sending_default_email_invites: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

show_a_join_from_your_browser_link: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

show_browser_join_link: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

show_device_list: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

show_meeting_control_toolbar: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

stereo_audio: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

use_html_format_email: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

virtual_background: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

virtual_background_settings: Option<VirtualBackgroundSettings>

Settings to manage virtual background.

waiting_room: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

whiteboard: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

who_can_share_screen: Option<WhoCanShareScreen>

Indicates who can share their screen or content during meetings. The value can be one of the following:
host: Only host can share the screen.
all: Both hosts and attendees can share their screen during meetings. For Webinar, the hosts and panelists can start screen sharing, but not the attendees.

who_can_share_screen_when_someone_is_sharing: Option<WhoCanShareScreen>

Indicates who can share their screen or content during meetings. The value can be one of the following:
host: Only host can share the screen.
all: Both hosts and attendees can share their screen during meetings. For Webinar, the hosts and panelists can start screen sharing, but not the attendees.