pub struct GetGroupSettingsResponseScheduleMeeting {Show 16 fields
pub audio_type: String,
pub embed_password_in_join_link: bool,
pub force_pmi_jbh_password: bool,
pub host_video: bool,
pub join_before_host: bool,
pub mute_upon_entry: bool,
pub participant_video: bool,
pub personal_meeting: bool,
pub pstn_password_protected: bool,
pub require_password_for_instant_meetings: bool,
pub require_password_for_pmi_meetings: Option<RequirePasswordPmiMeetings>,
pub require_password_for_scheduled_meetings: bool,
pub require_password_for_scheduling_new_meetings: bool,
pub upcoming_meeting_reminder: bool,
pub use_pmi_for_instant_meetings: bool,
pub use_pmi_for_schedule_meetings: bool,
}Fields
audio_type: StringUser’s first name.
embed_password_in_join_link: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
force_pmi_jbh_password: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
host_video: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
join_before_host: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
mute_upon_entry: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
participant_video: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
personal_meeting: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
pstn_password_protected: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
require_password_for_instant_meetings: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
require_password_for_pmi_meetings: Option<RequirePasswordPmiMeetings>Require a password for a meeting held using Personal Meeting ID (PMI) This setting is always enabled for free accounts and Pro accounts with a single host and cannot be modified for these accounts.
require_password_for_scheduled_meetings: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
require_password_for_scheduling_new_meetings: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
upcoming_meeting_reminder: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
use_pmi_for_instant_meetings: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
use_pmi_for_schedule_meetings: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.