Struct zoom_api::types::GetGroupSettingsResponseTelephony
source · pub struct GetGroupSettingsResponseTelephony {
pub audio_conference_info: String,
pub telephony_regions: Option<UpdateAccountSettingsTelephonyRegions>,
pub third_party_audio: bool,
}Fields
audio_conference_info: StringUser’s first name.
telephony_regions: Option<UpdateAccountSettingsTelephonyRegions>Indicates where most of the participants call into or call from duriing a meeting.
third_party_audio: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.