Struct zoom_api::types::GetPhoneNumberDetailsResponse
source · pub struct GetPhoneNumberDetailsResponse {
pub assignee: Option<Assignee>,
pub capability: Vec<String>,
pub carrier: Option<GetPhoneNumberDetailsResponseCarrier>,
pub display_name: String,
pub id: String,
pub location: String,
pub number: String,
pub number_type: Option<Type>,
pub sip_group: Option<AddCommonAreaPhoneResponse>,
pub site: Option<Site>,
pub source: Option<Source>,
pub status: Option<ListAccountPhoneNumbersResponseStatus>,
}Fields
assignee: Option<Assignee>capability: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.
carrier: Option<GetPhoneNumberDetailsResponseCarrier>display_name: StringUser’s first name.
id: StringUser’s first name.
location: StringUser’s first name.
number: StringUser’s first name.
number_type: Option<Type>Type of number.
sip_group: Option<AddCommonAreaPhoneResponse>site: Option<Site>source: Option<Source>Source of phone number.
status: Option<ListAccountPhoneNumbersResponseStatus>Status of the number.