pub struct GetSettingTemplateResponseUserSettings {
pub audio_prompt_language: String,
pub block_calls_without_caller_id: bool,
pub call_handling: Option<CallHandling>,
pub desk_phone: Option<GetSettingTemplateResponseUserSettingsDeskPhone>,
pub hold_music: Option<HoldMusic>,
}Fields
audio_prompt_language: StringUser’s first name.
block_calls_without_caller_id: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
call_handling: Option<CallHandling>desk_phone: Option<GetSettingTemplateResponseUserSettingsDeskPhone>hold_music: Option<HoldMusic>The value of this field can be either default or disable.
* default: This means that the hold music can be set using the audio library.
* disable: This means that the hold music is disabled.