Struct zoom_api::types::GetUserContactResponse
source · pub struct GetUserContactResponse {
pub direct_numbers: Vec<String>,
pub email: String,
pub extension_number: String,
pub first_name: String,
pub id: String,
pub last_name: String,
pub phone_number: String,
pub presence_status: Option<PresenceStatus>,
}Fields
direct_numbers: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.
email: StringUser’s first name.
extension_number: StringUser’s first name.
first_name: StringUser’s first name.
id: StringUser’s first name.
last_name: StringUser’s first name.
phone_number: StringUser’s first name.
presence_status: Option<PresenceStatus>Presence status of the contact in Zoom Client. The value of this field can be one of the following:
Do_Not_Disturb
away
Available
Offline