Struct zoom_api::types::GetZrProfileResponseBasic
source · pub struct GetZrProfileResponseBasic {
pub activation_code: String,
pub hide_room_in_contacts: bool,
pub name: String,
pub required_code_to_ext: bool,
pub room_passcode: String,
pub support_email: String,
pub support_phone: String,
}Fields
activation_code: StringUser’s first name.
hide_room_in_contacts: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
name: StringUser’s first name.
required_code_to_ext: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
room_passcode: StringUser’s first name.
support_email: StringUser’s first name.
support_phone: StringUser’s first name.