Struct zoom_api::types::ImChatSessionsResponseAllOf
source · pub struct ImChatSessionsResponseAllOf {
pub pagination_token_4_im_chat: PaginationToken4ImChat,
pub dashboard_im_response: DashboardImResponse,
pub im_chat_sessions_response_data: ImChatSessionsResponseData,
}Expand description
All of the following types are flattened into one object:
PaginationToken4ImChatDashboardImResponseImChatSessionsResponseData
Fields
pagination_token_4_im_chat: PaginationToken4ImChatPagination object.
dashboard_im_response: DashboardImResponseim_chat_sessions_response_data: ImChatSessionsResponseDataTrait Implementations
sourceimpl Clone for ImChatSessionsResponseAllOf
impl Clone for ImChatSessionsResponseAllOf
sourcefn clone(&self) -> ImChatSessionsResponseAllOf
fn clone(&self) -> ImChatSessionsResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ImChatSessionsResponseAllOf
impl Debug for ImChatSessionsResponseAllOf
sourceimpl<'de> Deserialize<'de> for ImChatSessionsResponseAllOf
impl<'de> Deserialize<'de> for ImChatSessionsResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for ImChatSessionsResponseAllOf
impl JsonSchema for ImChatSessionsResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<ImChatSessionsResponseAllOf> for ImChatSessionsResponseAllOf
impl PartialEq<ImChatSessionsResponseAllOf> for ImChatSessionsResponseAllOf
sourcefn eq(&self, other: &ImChatSessionsResponseAllOf) -> bool
fn eq(&self, other: &ImChatSessionsResponseAllOf) -> bool
impl StructuralPartialEq for ImChatSessionsResponseAllOf