Struct zoom_api::types::ImGroupCreateResponse
source · pub struct ImGroupCreateResponse {
pub id: String,
pub name: String,
pub search_by_account: bool,
pub search_by_domain: bool,
pub search_by_ma_account: bool,
pub total_members: i64,
}Fields
id: StringUser’s first name.
name: StringUser’s first name.
search_by_account: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
search_by_domain: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
search_by_ma_account: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
total_members: i64Account seats.