Struct zoom_api::types::ImGroupResponseAllOf
source · Expand description
All of the following types are flattened into one object:
DomainsGroups
Fields
domains: Domainsgroups: GroupsTrait Implementations
sourceimpl Clone for ImGroupResponseAllOf
impl Clone for ImGroupResponseAllOf
sourcefn clone(&self) -> ImGroupResponseAllOf
fn clone(&self) -> ImGroupResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ImGroupResponseAllOf
impl Debug for ImGroupResponseAllOf
sourceimpl<'de> Deserialize<'de> for ImGroupResponseAllOf
impl<'de> Deserialize<'de> for ImGroupResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for ImGroupResponseAllOf
impl JsonSchema for ImGroupResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<ImGroupResponseAllOf> for ImGroupResponseAllOf
impl PartialEq<ImGroupResponseAllOf> for ImGroupResponseAllOf
sourcefn eq(&self, other: &ImGroupResponseAllOf) -> bool
fn eq(&self, other: &ImGroupResponseAllOf) -> bool
sourceimpl Serialize for ImGroupResponseAllOf
impl Serialize for ImGroupResponseAllOf
impl StructuralPartialEq for ImGroupResponseAllOf