Struct zoom_api::types::InviteChannelMembersResponse
source · pub struct InviteChannelMembersResponse {
pub added_at: Option<DateTime<Utc>>,
pub ids: Vec<String>,
}Fields
added_at: Option<DateTime<Utc>>Account subscription start date and time.
ids: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.