Struct zoom_api::types::IpAddressAccessControl
source · Expand description
Setting to allow cloud recording access only from specific IP address ranges.
Fields
enable: boolSetting to allow cloud recording access only from specific IP address ranges.
ip_addresses_or_ranges: StringSetting to allow cloud recording access only from specific IP address ranges.