Struct zoom_api::types::LanguageInterpretation
source · pub struct LanguageInterpretation {
pub enable: bool,
pub interpreters: Vec<Interpreters>,
}Fields
enable: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
interpreters: Vec<Interpreters>Information associated with the interpreter.