Struct zoom_api::types::MeetingCreateResponseAllOf
source · pub struct MeetingCreateResponseAllOf {
pub meeting_info: MeetingInfo,
pub meeting_create_response: MeetingCreateResponse,
}Expand description
All of the following types are flattened into one object:
MeetingInfoMeetingCreateResponse
Fields
meeting_info: MeetingInfoMeeting object
meeting_create_response: MeetingCreateResponseTrait Implementations
sourceimpl Clone for MeetingCreateResponseAllOf
impl Clone for MeetingCreateResponseAllOf
sourcefn clone(&self) -> MeetingCreateResponseAllOf
fn clone(&self) -> MeetingCreateResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for MeetingCreateResponseAllOf
impl Debug for MeetingCreateResponseAllOf
sourceimpl<'de> Deserialize<'de> for MeetingCreateResponseAllOf
impl<'de> Deserialize<'de> for MeetingCreateResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for MeetingCreateResponseAllOf
impl JsonSchema for MeetingCreateResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<MeetingCreateResponseAllOf> for MeetingCreateResponseAllOf
impl PartialEq<MeetingCreateResponseAllOf> for MeetingCreateResponseAllOf
sourcefn eq(&self, other: &MeetingCreateResponseAllOf) -> bool
fn eq(&self, other: &MeetingCreateResponseAllOf) -> bool
impl StructuralPartialEq for MeetingCreateResponseAllOf