pub struct MeetingCreateSettingsLanguageInterpretation {
pub enable: bool,
pub interpreters: Vec<Interpreters>,
}Expand description
Language interpretation settings for meetings.
Note: This feature is only available on certain Webinar add-on, Education, Business and higher plans. If this feature is not enabled on the host’s account, this setting will not be applied for the meeting.
Fields
enable: boolLanguage interpretation settings for meetings.
**Note:** This feature is only available on certain Webinar add-on, Education, Business and higher plans. If this feature is not enabled on the host’s account, this setting will not be applied for the meeting.
interpreters: Vec<Interpreters>Language interpretation settings for meetings.
**Note:** This feature is only available on certain Webinar add-on, Education, Business and higher plans. If this feature is not enabled on the host’s account, this setting will not be applied for the meeting.