Struct zoom_api::types::MeetingLiveStreamStatusSettings
source · pub struct MeetingLiveStreamStatusSettings {
pub active_speaker_name: bool,
pub display_name: String,
}Expand description
Update the settings of a live streaming session. The settings can only be updated for a live stream that has been stopped. You can not update the settings of an ongoing live stream.
Fields
active_speaker_name: boolUpdate the settings of a live streaming session. The settings can only be updated for a live stream that has been stopped. You can not update the settings of an ongoing live stream.
display_name: StringUpdate the settings of a live streaming session. The settings can only be updated for a live stream that has been stopped. You can not update the settings of an ongoing live stream.