Struct zoom_api::types::MeetingPollGetResponseAllOf
source · pub struct MeetingPollGetResponseAllOf {
pub poll: Poll,
pub meeting_poll_get_response: MeetingPollGetResponse,
}Expand description
All of the following types are flattened into one object:
PollMeetingPollGetResponse
Fields
poll: PollPoll
meeting_poll_get_response: MeetingPollGetResponseTrait Implementations
sourceimpl Clone for MeetingPollGetResponseAllOf
impl Clone for MeetingPollGetResponseAllOf
sourcefn clone(&self) -> MeetingPollGetResponseAllOf
fn clone(&self) -> MeetingPollGetResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for MeetingPollGetResponseAllOf
impl Debug for MeetingPollGetResponseAllOf
sourceimpl<'de> Deserialize<'de> for MeetingPollGetResponseAllOf
impl<'de> Deserialize<'de> for MeetingPollGetResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for MeetingPollGetResponseAllOf
impl JsonSchema for MeetingPollGetResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<MeetingPollGetResponseAllOf> for MeetingPollGetResponseAllOf
impl PartialEq<MeetingPollGetResponseAllOf> for MeetingPollGetResponseAllOf
sourcefn eq(&self, other: &MeetingPollGetResponseAllOf) -> bool
fn eq(&self, other: &MeetingPollGetResponseAllOf) -> bool
impl StructuralPartialEq for MeetingPollGetResponseAllOf