Struct zoom_api::types::MeetingRegistrantQuestions
source · Fields
field_name: Option<FieldName>Field name of the question.
required: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.