Struct zoom_api::types::MeetingResponseAllOf
source · pub struct MeetingResponseAllOf {
pub meeting_info_get: MeetingInfoGet,
pub meeting_response: MeetingResponse,
}Expand description
All of the following types are flattened into one object:
MeetingInfoGetMeetingResponse
Fields
meeting_info_get: MeetingInfoGetMeeting object.
meeting_response: MeetingResponseTrait Implementations
sourceimpl Clone for MeetingResponseAllOf
impl Clone for MeetingResponseAllOf
sourcefn clone(&self) -> MeetingResponseAllOf
fn clone(&self) -> MeetingResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for MeetingResponseAllOf
impl Debug for MeetingResponseAllOf
sourceimpl<'de> Deserialize<'de> for MeetingResponseAllOf
impl<'de> Deserialize<'de> for MeetingResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for MeetingResponseAllOf
impl JsonSchema for MeetingResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<MeetingResponseAllOf> for MeetingResponseAllOf
impl PartialEq<MeetingResponseAllOf> for MeetingResponseAllOf
sourcefn eq(&self, other: &MeetingResponseAllOf) -> bool
fn eq(&self, other: &MeetingResponseAllOf) -> bool
sourceimpl Serialize for MeetingResponseAllOf
impl Serialize for MeetingResponseAllOf
impl StructuralPartialEq for MeetingResponseAllOf