pub struct MeetingSecurity {
Show 15 fields pub auto_security: bool, pub block_user_domain: bool, pub block_user_domain_list: Vec<String>, pub embed_password_in_join_link: bool, pub encryption_type: Option<EncryptionType>, pub end_to_end_encrypted_meetings: bool, pub meeting_password: bool, pub meeting_password_requirement: Option<MeetingSecuritySettingsPasswordRequirement>, pub phone_password: bool, pub pmi_password: bool, pub require_password_for_scheduled_meeting: bool, pub require_password_for_scheduled_webinar: bool, pub waiting_room: bool, pub waiting_room_settings: Option<WaitingRoomSettings>, pub webinar_password: bool,
}

Fields

auto_security: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

block_user_domain: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

block_user_domain_list: Vec<String>

Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.

**Note:** This option can only be used if the value of share_rc is set to true.

embed_password_in_join_link: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

encryption_type: Option<EncryptionType>

Choose between enhanced encryption and end-to-end encryption when starting or a meeting. When using end-to-end encryption, several features (e.g. cloud recording, phone/SIP/H.323 dial-in) will be **automatically disabled**.

The value of this field can be one of the following:
enhanced_encryption: Enhanced encryption. Encryption is stored in the cloud if you enable this option.

e2ee: End-to-end encryption. The encryption key is stored in your local device and can not be obtained by anyone else. Enabling this setting also **disables** the following features: join before host, cloud recording, streaming, live transcription, breakout rooms, polling, 1:1 private chat, and meeting reactions.

end_to_end_encrypted_meetings: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

meeting_password: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

meeting_password_requirement: Option<MeetingSecuritySettingsPasswordRequirement>

Meeting/webinar passcode requirements.

phone_password: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

pmi_password: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

require_password_for_scheduled_meeting: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

require_password_for_scheduled_webinar: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

waiting_room: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.

waiting_room_settings: Option<WaitingRoomSettings>

Specify the settings to be applied if waiting room is enabled.

webinar_password: bool

Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.