Struct zoom_api::types::MeetingUpdateRequestAllOf
source · pub struct MeetingUpdateRequestAllOf {
pub domains: Domains,
pub meeting_update_request: MeetingUpdateRequest,
}Expand description
All of the following types are flattened into one object:
DomainsMeetingUpdateRequest
Fields
domains: Domainsmeeting_update_request: MeetingUpdateRequestTrait Implementations
sourceimpl Clone for MeetingUpdateRequestAllOf
impl Clone for MeetingUpdateRequestAllOf
sourcefn clone(&self) -> MeetingUpdateRequestAllOf
fn clone(&self) -> MeetingUpdateRequestAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for MeetingUpdateRequestAllOf
impl Debug for MeetingUpdateRequestAllOf
sourceimpl<'de> Deserialize<'de> for MeetingUpdateRequestAllOf
impl<'de> Deserialize<'de> for MeetingUpdateRequestAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for MeetingUpdateRequestAllOf
impl JsonSchema for MeetingUpdateRequestAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<MeetingUpdateRequestAllOf> for MeetingUpdateRequestAllOf
impl PartialEq<MeetingUpdateRequestAllOf> for MeetingUpdateRequestAllOf
sourcefn eq(&self, other: &MeetingUpdateRequestAllOf) -> bool
fn eq(&self, other: &MeetingUpdateRequestAllOf) -> bool
sourceimpl Serialize for MeetingUpdateRequestAllOf
impl Serialize for MeetingUpdateRequestAllOf
impl StructuralPartialEq for MeetingUpdateRequestAllOf