Struct zoom_api::types::OutboundCallerIds
source · Fields
is_default: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
name: StringUser’s first name.
number: StringUser’s first name.