Struct zoom_api::types::PanelistsAllOf
source · Expand description
All of the following types are flattened into one object:
GroupsPanelistPanelists
Fields
groups: Groupspanelist: PanelistPanelist base object.
panelists: PanelistsTrait Implementations
sourceimpl Clone for PanelistsAllOf
impl Clone for PanelistsAllOf
sourcefn clone(&self) -> PanelistsAllOf
fn clone(&self) -> PanelistsAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for PanelistsAllOf
impl Debug for PanelistsAllOf
sourceimpl<'de> Deserialize<'de> for PanelistsAllOf
impl<'de> Deserialize<'de> for PanelistsAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for PanelistsAllOf
impl JsonSchema for PanelistsAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<PanelistsAllOf> for PanelistsAllOf
impl PartialEq<PanelistsAllOf> for PanelistsAllOf
sourcefn eq(&self, other: &PanelistsAllOf) -> bool
fn eq(&self, other: &PanelistsAllOf) -> bool
sourceimpl Serialize for PanelistsAllOf
impl Serialize for PanelistsAllOf
impl StructuralPartialEq for PanelistsAllOf