Struct zoom_api::types::PasswordRequirement
source · pub struct PasswordRequirement {
pub consecutive_characters_length: i64,
pub have_special_character: bool,
pub minimum_password_length: i64,
pub weak_enhance_detection: bool,
}Expand description
This object refers to the enhanced password rules that allows Zoom account admins and owners to apply extra requiremets to the users’ Zoom login password.
Fields
consecutive_characters_length: i64This object refers to the enhanced password rules that allows Zoom account admins and owners to apply extra requiremets to the users’ Zoom login password.
have_special_character: boolThis object refers to the enhanced password rules that allows Zoom account admins and owners to apply extra requiremets to the users’ Zoom login password.
minimum_password_length: i64This object refers to the enhanced password rules that allows Zoom account admins and owners to apply extra requiremets to the users’ Zoom login password.
weak_enhance_detection: boolThis object refers to the enhanced password rules that allows Zoom account admins and owners to apply extra requiremets to the users’ Zoom login password.