pub struct PastMeetingParticipantsResponseAllOf {
pub pagination_token: PaginationToken,
pub past_meeting_participants_response: PastMeetingParticipantsResponse,
}Expand description
All of the following types are flattened into one object:
PaginationTokenPastMeetingParticipantsResponse
Fields
pagination_token: PaginationTokenPagination object.
past_meeting_participants_response: PastMeetingParticipantsResponseTrait Implementations
sourceimpl Clone for PastMeetingParticipantsResponseAllOf
impl Clone for PastMeetingParticipantsResponseAllOf
sourcefn clone(&self) -> PastMeetingParticipantsResponseAllOf
fn clone(&self) -> PastMeetingParticipantsResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for PastMeetingParticipantsResponseAllOf
impl<'de> Deserialize<'de> for PastMeetingParticipantsResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for PastMeetingParticipantsResponseAllOf
impl JsonSchema for PastMeetingParticipantsResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<PastMeetingParticipantsResponseAllOf> for PastMeetingParticipantsResponseAllOf
impl PartialEq<PastMeetingParticipantsResponseAllOf> for PastMeetingParticipantsResponseAllOf
sourcefn eq(&self, other: &PastMeetingParticipantsResponseAllOf) -> bool
fn eq(&self, other: &PastMeetingParticipantsResponseAllOf) -> bool
impl StructuralPartialEq for PastMeetingParticipantsResponseAllOf