Struct zoom_api::types::ProvisionTemplate
source · Fields
id: StringUser’s first name.
name: StringUser’s first name.
supported: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.