pub struct ReportMeetingParticipantsResponseAllOf {
pub pagination_token: PaginationToken,
pub report_meeting_participants_response_data: ReportMeetingParticipantsResponseData,
}Expand description
All of the following types are flattened into one object:
PaginationTokenReportMeetingParticipantsResponseData
Fields
pagination_token: PaginationTokenPagination object.
report_meeting_participants_response_data: ReportMeetingParticipantsResponseDataTrait Implementations
sourceimpl Clone for ReportMeetingParticipantsResponseAllOf
impl Clone for ReportMeetingParticipantsResponseAllOf
sourcefn clone(&self) -> ReportMeetingParticipantsResponseAllOf
fn clone(&self) -> ReportMeetingParticipantsResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for ReportMeetingParticipantsResponseAllOf
impl<'de> Deserialize<'de> for ReportMeetingParticipantsResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for ReportMeetingParticipantsResponseAllOf
impl JsonSchema for ReportMeetingParticipantsResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<ReportMeetingParticipantsResponseAllOf> for ReportMeetingParticipantsResponseAllOf
impl PartialEq<ReportMeetingParticipantsResponseAllOf> for ReportMeetingParticipantsResponseAllOf
sourcefn eq(&self, other: &ReportMeetingParticipantsResponseAllOf) -> bool
fn eq(&self, other: &ReportMeetingParticipantsResponseAllOf) -> bool
impl StructuralPartialEq for ReportMeetingParticipantsResponseAllOf