Struct zoom_api::types::ReportMeetingsResponseAllOf
source · pub struct ReportMeetingsResponseAllOf {
pub pagination: Pagination,
pub report_meetings_response: ReportMeetingsResponse,
}Expand description
All of the following types are flattened into one object:
PaginationReportMeetingsResponse
Fields
pagination: PaginationPagination Object.
report_meetings_response: ReportMeetingsResponseTrait Implementations
sourceimpl Clone for ReportMeetingsResponseAllOf
impl Clone for ReportMeetingsResponseAllOf
sourcefn clone(&self) -> ReportMeetingsResponseAllOf
fn clone(&self) -> ReportMeetingsResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ReportMeetingsResponseAllOf
impl Debug for ReportMeetingsResponseAllOf
sourceimpl<'de> Deserialize<'de> for ReportMeetingsResponseAllOf
impl<'de> Deserialize<'de> for ReportMeetingsResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for ReportMeetingsResponseAllOf
impl JsonSchema for ReportMeetingsResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<ReportMeetingsResponseAllOf> for ReportMeetingsResponseAllOf
impl PartialEq<ReportMeetingsResponseAllOf> for ReportMeetingsResponseAllOf
sourcefn eq(&self, other: &ReportMeetingsResponseAllOf) -> bool
fn eq(&self, other: &ReportMeetingsResponseAllOf) -> bool
impl StructuralPartialEq for ReportMeetingsResponseAllOf