Struct zoom_api::types::ReportOperationLogsResponseAllOf
source · pub struct ReportOperationLogsResponseAllOf {
pub pagination_token_4_im_chat: PaginationToken4ImChat,
pub report_operation_logs_response: ReportOperationLogsResponse,
}Expand description
All of the following types are flattened into one object:
PaginationToken4ImChatReportOperationLogsResponse
Fields
pagination_token_4_im_chat: PaginationToken4ImChatPagination object.
report_operation_logs_response: ReportOperationLogsResponseTrait Implementations
sourceimpl Clone for ReportOperationLogsResponseAllOf
impl Clone for ReportOperationLogsResponseAllOf
sourcefn clone(&self) -> ReportOperationLogsResponseAllOf
fn clone(&self) -> ReportOperationLogsResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for ReportOperationLogsResponseAllOf
impl<'de> Deserialize<'de> for ReportOperationLogsResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for ReportOperationLogsResponseAllOf
impl JsonSchema for ReportOperationLogsResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<ReportOperationLogsResponseAllOf> for ReportOperationLogsResponseAllOf
impl PartialEq<ReportOperationLogsResponseAllOf> for ReportOperationLogsResponseAllOf
sourcefn eq(&self, other: &ReportOperationLogsResponseAllOf) -> bool
fn eq(&self, other: &ReportOperationLogsResponseAllOf) -> bool
impl StructuralPartialEq for ReportOperationLogsResponseAllOf