Struct zoom_api::types::ReportWebinarParticipantsResponse
source · pub struct ReportWebinarParticipantsResponse {
pub customer_key: String,
pub duration: i64,
pub failover: bool,
pub id: String,
pub join_time: Option<DateTime<Utc>>,
pub leave_time: Option<DateTime<Utc>>,
pub name: String,
pub user_email: String,
pub user_id: String,
}Fields
customer_key: StringUser’s first name.
duration: i64Account seats.
failover: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
id: StringUser’s first name.
join_time: Option<DateTime<Utc>>Account subscription start date and time.
leave_time: Option<DateTime<Utc>>Account subscription start date and time.
name: StringUser’s first name.
user_email: StringUser’s first name.
user_id: StringUser’s first name.