pub struct ReportWebinarParticipantsResponseAllOf {
pub pagination_token: PaginationToken,
pub report_webinar_participants_response_data: ReportWebinarParticipantsResponseData,
}Expand description
All of the following types are flattened into one object:
PaginationTokenReportWebinarParticipantsResponseData
Fields
pagination_token: PaginationTokenPagination object.
report_webinar_participants_response_data: ReportWebinarParticipantsResponseDataTrait Implementations
sourceimpl Clone for ReportWebinarParticipantsResponseAllOf
impl Clone for ReportWebinarParticipantsResponseAllOf
sourcefn clone(&self) -> ReportWebinarParticipantsResponseAllOf
fn clone(&self) -> ReportWebinarParticipantsResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for ReportWebinarParticipantsResponseAllOf
impl<'de> Deserialize<'de> for ReportWebinarParticipantsResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for ReportWebinarParticipantsResponseAllOf
impl JsonSchema for ReportWebinarParticipantsResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<ReportWebinarParticipantsResponseAllOf> for ReportWebinarParticipantsResponseAllOf
impl PartialEq<ReportWebinarParticipantsResponseAllOf> for ReportWebinarParticipantsResponseAllOf
sourcefn eq(&self, other: &ReportWebinarParticipantsResponseAllOf) -> bool
fn eq(&self, other: &ReportWebinarParticipantsResponseAllOf) -> bool
impl StructuralPartialEq for ReportWebinarParticipantsResponseAllOf