Struct zoom_api::types::SendchatbotRequest
source · pub struct SendchatbotRequest {
pub account_id: String,
pub content: Domains,
pub is_markdown_support: Option<bool>,
pub robot_jid: String,
pub to_jid: String,
pub user_jid: String,
pub visible_to_user: String,
}Fields
account_id: StringUser’s first name.
content: Domainsis_markdown_support: Option<bool>Enable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
robot_jid: StringUser’s first name.
to_jid: StringUser’s first name.
user_jid: StringUser’s first name.
visible_to_user: StringUser’s first name.