Struct zoom_api::types::SettingsAllOf
source · pub struct SettingsAllOf {
pub meeting_settings: MeetingSettings,
pub settings_data: SettingsData,
}Expand description
All of the following types are flattened into one object:
MeetingSettingsSettingsData
Fields
meeting_settings: MeetingSettingsMeeting settings.
settings_data: SettingsDataTrait Implementations
sourceimpl Clone for SettingsAllOf
impl Clone for SettingsAllOf
sourcefn clone(&self) -> SettingsAllOf
fn clone(&self) -> SettingsAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for SettingsAllOf
impl Debug for SettingsAllOf
sourceimpl<'de> Deserialize<'de> for SettingsAllOf
impl<'de> Deserialize<'de> for SettingsAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for SettingsAllOf
impl JsonSchema for SettingsAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<SettingsAllOf> for SettingsAllOf
impl PartialEq<SettingsAllOf> for SettingsAllOf
sourcefn eq(&self, other: &SettingsAllOf) -> bool
fn eq(&self, other: &SettingsAllOf) -> bool
sourceimpl Serialize for SettingsAllOf
impl Serialize for SettingsAllOf
impl StructuralPartialEq for SettingsAllOf