Struct zoom_api::types::SettingsData
source · pub struct SettingsData {
pub registrants_confirmation_email: bool,
}Fields
registrants_confirmation_email: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.