Struct zoom_api::types::ShowDeviceIpCallLog
source · pub struct ShowDeviceIpCallLog {
pub enable: bool,
}Fields
enable: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.