pub struct SipGroups {
pub description: String,
pub display_name: String,
pub id: String,
pub send_sip_group_name: bool,
pub sip_trunk: Option<SipTrunk>,
}Fields
description: StringUser’s first name.
display_name: StringUser’s first name.
id: StringUser’s first name.
send_sip_group_name: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
sip_trunk: Option<SipTrunk>The SIP trunk group.