Struct zoom_api::types::SubAccountPrivileges
source · pub struct SubAccountPrivileges {
pub second_level: i64,
}Expand description
This field will only be displayed to accounts that are enrolled in a partner plan and follow the master accounts and sub accounts structure.
Fields
second_level: i64This field will only be displayed to accounts that are enrolled in a partner plan and follow the master accounts and sub accounts structure.