Struct zoom_api::types::TelephonyRegions
source · Expand description
Indicates where most of the participants call into or call from duriing a meeting.
Fields
allowed_values: Vec<String>Indicates where most of the participants call into or call from duriing a meeting.
selection_values: Vec<String>Indicates where most of the participants call into or call from duriing a meeting.