Struct zoom_api::types::TrackingFields
source · Fields
field: StringUser’s first name.
value: StringUser’s first name.
visible: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.