Indicates where most of the participants call into or call from duriing a meeting.
Fields
selection_values: Vec<String>Indicates where most of the participants call into or call from duriing a meeting.