Struct zoom_api::types::UpdateBlockedListRequest
source · pub struct UpdateBlockedListRequest {
pub block_type: Option<Direction>,
pub comment: String,
pub match_type: Option<MatchType>,
pub phone_number: String,
pub status: Option<ReportUsersType>,
}Fields
block_type: Option<Direction>The direction of the call. Values: inbound or outbound.
comment: StringUser’s first name.
match_type: Option<MatchType>Indicates the match type for the blocked list. The values can be one of the following:
phoneNumber: Indicates that only a specific phone number that is shown in the phone_number field is blocked.
prefix: Indicates that all numbers starting with prefix that is shown in the phone_number field are blocked.
phone_number: StringUser’s first name.
status: Option<ReportUsersType>Active or inactive hosts.active - Active hosts. inactive - Inactive hosts.