pub struct UpdateGroupSettingsRequestTelephony {
pub audio_conference_info: String,
pub third_party_audio: bool,
}Fields
audio_conference_info: StringUser’s first name.
third_party_audio: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.