Struct zoom_api::types::UpdatePhoneNumberDetailsRequest
source · pub struct UpdatePhoneNumberDetailsRequest {
pub capability: Vec<String>,
pub display_name: String,
pub sip_group_id: String,
}Fields
capability: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.
display_name: StringUser’s first name.
sip_group_id: StringUser’s first name.