Struct zoom_api::types::UpdatePresenceStatusRequestData
source · pub struct UpdatePresenceStatusRequestData {
pub duration: i64,
pub status: Option<UpdatePresenceStatusRequest>,
}Fields
duration: i64Account seats.
status: Option<UpdatePresenceStatusRequest>Presence status of the user. The value can be set to one of the following:
* Away
* Do_Not_Disturb
* Available
* In_Calendar_Event
* Presenting
* In_A_Zoom_Meeting
* On_A_Call
Users who are on Zoom Client with a version **lower than 5.3.0** can update the status from:
* Away to Do_Not_Disturb
* Available to Do_Not_Disturb
Users who are on **Zoom Client 5.3.0** or higher can update the status from:
* Do_Not_Disturb to Away
* Do_Not_Disturb to Available
* Available to Away
* Away to Available