Struct zoom_api::types::UpdateRoleRequest
source · pub struct UpdateRoleRequest {
pub description: String,
pub id: String,
pub name: String,
pub privileges: Vec<String>,
pub sub_account_privileges: Option<UpdateRoleRequestSubAccountPrivileges>,
pub total_members: i64,
}Fields
description: StringUser’s first name.
id: StringUser’s first name.
name: StringUser’s first name.
privileges: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.
sub_account_privileges: Option<UpdateRoleRequestSubAccountPrivileges>This field will only be displayed to accounts that are enrolled in the partner plan and follow master accounts and sub accounts structure.
total_members: i64Account seats.