pub struct UpdateRoleRequestSubAccountPrivileges {
pub second_level: i64,
}Expand description
This field will only be displayed to accounts that are enrolled in the partner plan and follow master accounts and sub accounts structure.
Fields
second_level: i64This field will only be displayed to accounts that are enrolled in the partner plan and follow master accounts and sub accounts structure.