Struct zoom_api::types::User

source ·
pub struct User {
    pub created_at: Option<DateTime<Utc>>,
    pub dept: String,
    pub email: String,
    pub first_name: String,
    pub last_client_version: String,
    pub last_login_time: Option<DateTime<Utc>>,
    pub last_name: String,
    pub pmi: i64,
    pub role_name: String,
    pub timezone: String,
    pub type_: i64,
    pub use_pmi: bool,
}
The user object represents a specific user on Zoom.

Fields

created_at: Option<DateTime<Utc>>

The user object represents a specific user on Zoom.

dept: String

The user object represents a specific user on Zoom.

email: String

User’s first name.

first_name: String

The user object represents a specific user on Zoom.

last_client_version: String

The user object represents a specific user on Zoom.

last_login_time: Option<DateTime<Utc>>

The user object represents a specific user on Zoom.

last_name: String

The user object represents a specific user on Zoom.

pmi: i64

The user object represents a specific user on Zoom.

role_name: String

The user object represents a specific user on Zoom.

timezone: String

The user object represents a specific user on Zoom.

type_: i64

Account seats.

use_pmi: bool

The user object represents a specific user on Zoom.