Struct zoom_api::types::UserCreateRequest
source · pub struct UserCreateRequest {
pub action: UserCreateRequestAction,
pub user_info: Option<UserInfo>,
}Fields
action: UserCreateRequestActionSpecify how to create the new user: create - User will get an email sent from Zoom. There is a confirmation link in this email. The user will then need to use the link to activate their Zoom account. The user can then set or change their password.autoCreate - This action is provided for the enterprise customer who has a managed domain. This feature is disabled by default because of the security risk involved in creating a user who does not belong to your domain.custCreate - Users created via this option do not have passwords and will not have the ability to log into the Zoom Web Portal or the Zoom Client. These users can still host and join meetings using the start_url and join_url respectively. To use this option, you must contact the ISV Platform Sales team at isv@zoom.us.ssoCreate - This action is provided for the enabled “Pre-provisioning SSO User” option. A user created in this way has no password. If not a basic user, a personal vanity URL using the user name (no domain) of the provisioning email will be generated. If the user name or PMI is invalid or occupied, it will use a random number or random personal vanity URL.
user_info: Option<UserInfo>Trait Implementations
sourceimpl Clone for UserCreateRequest
impl Clone for UserCreateRequest
sourcefn clone(&self) -> UserCreateRequest
fn clone(&self) -> UserCreateRequest
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for UserCreateRequest
impl Debug for UserCreateRequest
sourceimpl<'de> Deserialize<'de> for UserCreateRequest
impl<'de> Deserialize<'de> for UserCreateRequest
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
sourceimpl JsonSchema for UserCreateRequest
impl JsonSchema for UserCreateRequest
sourcefn schema_name() -> String
fn schema_name() -> String
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
$ref keyword. Read more