Struct zoom_api::types::UserEmailResponse
source · pub struct UserEmailResponse {
pub existed_email: bool,
}Fields
existed_email: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.