Struct zoom_api::types::UserQos

source ·
pub struct UserQos {
Show 14 fields pub as_device_from_crc: Option<AsDeviceFromCrc>, pub as_device_to_crc: Option<AsDeviceCrc>, pub as_input: Option<Domains>, pub as_output: Option<Domains>, pub audio_device_from_crc: Option<AudioDeviceFromCrc>, pub audio_device_to_crc: Option<AudioDeviceCrc>, pub audio_input: Option<QosAudio>, pub audio_output: Option<QosAudio>, pub cpu_usage: Option<CpuUsage>, pub date_time: Option<DateTime<Utc>>, pub video_device_from_crc: Option<VideoDeviceFromCrc>, pub video_device_to_crc: Option<VideoDeviceCrc>, pub video_input: Option<Domains>, pub video_output: Option<Domains>,
}

Fields

as_device_from_crc: Option<AsDeviceFromCrc>

QoS metrics on screen shares by a participant who joined the meeting via a Cloud Room Connector.

as_device_to_crc: Option<AsDeviceCrc>

QoS metrics on screen shares output being received by a participant who joined the meeting via a Cloud Room Connector.

as_input: Option<Domains>as_output: Option<Domains>audio_device_from_crc: Option<AudioDeviceFromCrc>

QoS metrics on audio being sent by a participant who joined the meeting via a Cloud Room Connector.

audio_device_to_crc: Option<AudioDeviceCrc>

QoS metrics on audio received by a participant who joined the meeting via a Cloud Room Connector.

audio_input: Option<QosAudio>

Quality of Service object.

audio_output: Option<QosAudio>

Quality of Service object.

cpu_usage: Option<CpuUsage>date_time: Option<DateTime<Utc>>

Account subscription start date and time.

video_device_from_crc: Option<VideoDeviceFromCrc>

QoS metrics on video input being sent from a Cloud Room Connector used by the participant to join the meeting.

video_device_to_crc: Option<VideoDeviceCrc>

QoS metrics on video output received by a participant who joined the meeting via a Cloud Room Connector.

video_input: Option<Domains>video_output: Option<Domains>