Struct zoom_api::types::UserResponse
source · pub struct UserResponse {Show 25 fields
pub account_id: String,
pub cms_user_id: String,
pub company: String,
pub created_at: Option<DateTime<Utc>>,
pub custom_attributes: Option<UserResponseCustomAttributes>,
pub group_ids: Vec<String>,
pub host_key: String,
pub im_group_ids: Vec<String>,
pub jid: String,
pub job_title: String,
pub language: String,
pub location: String,
pub login_type: i64,
pub manager: String,
pub personal_meeting_url: String,
pub phone_country: String,
pub phone_number: String,
pub phone_numbers: Option<UserResponsePhoneNumbers>,
pub pic_url: String,
pub plan_united_type: String,
pub role_id: String,
pub status: Option<UsersStatus>,
pub use_pmi: bool,
pub vanity_url: String,
pub verified: i64,
}Fields
account_id: StringUser’s first name.
cms_user_id: StringUser’s first name.
company: StringUser’s first name.
created_at: Option<DateTime<Utc>>Account subscription start date and time.
custom_attributes: Option<UserResponseCustomAttributes>Custom attribute(s) that have been assigned to the user.
group_ids: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.
host_key: StringUser’s first name.
im_group_ids: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.
jid: StringUser’s first name.
job_title: StringUser’s first name.
language: StringUser’s first name.
location: StringUser’s first name.
login_type: i64Account seats.
manager: StringUser’s first name.
personal_meeting_url: StringUser’s first name.
phone_country: StringUser’s first name.
phone_number: StringUser’s first name.
phone_numbers: Option<UserResponsePhoneNumbers>pic_url: StringUser’s first name.
plan_united_type: StringUser’s first name.
role_id: StringUser’s first name.
status: Option<UsersStatus>The user’s status:
* active — An active user.
* inactive — A deactivated user.
* pending — A pending user.
This value defaults to active.
use_pmi: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
vanity_url: StringUser’s first name.
verified: i64Account seats.