Struct zoom_api::types::UserResponseAllOf
source · pub struct UserResponseAllOf {
pub groups: Groups,
pub user: User,
pub user_response: UserResponse,
}Expand description
All of the following types are flattened into one object:
GroupsUserUserResponse
Fields
groups: Groupsuser: UserThe user object represents a specific user on Zoom.
user_response: UserResponseTrait Implementations
sourceimpl Clone for UserResponseAllOf
impl Clone for UserResponseAllOf
sourcefn clone(&self) -> UserResponseAllOf
fn clone(&self) -> UserResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for UserResponseAllOf
impl Debug for UserResponseAllOf
sourceimpl<'de> Deserialize<'de> for UserResponseAllOf
impl<'de> Deserialize<'de> for UserResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for UserResponseAllOf
impl JsonSchema for UserResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<UserResponseAllOf> for UserResponseAllOf
impl PartialEq<UserResponseAllOf> for UserResponseAllOf
sourcefn eq(&self, other: &UserResponseAllOf) -> bool
fn eq(&self, other: &UserResponseAllOf) -> bool
sourceimpl Serialize for UserResponseAllOf
impl Serialize for UserResponseAllOf
impl StructuralPartialEq for UserResponseAllOf