Struct zoom_api::types::UserResponsePhoneNumbers
source · pub struct UserResponsePhoneNumbers {
pub code: String,
pub country: String,
pub label: Option<Label>,
pub number: String,
pub verified: bool,
}Fields
code: StringUser’s first name.
country: StringUser’s first name.
label: Option<Label>The label to add to the user’s phone number. You can only add one label to the user’s phone number:
* Mobile
* Office
* Home
* Fax
number: StringUser’s first name.
verified: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.