Struct zoom_api::types::UserVanityNameResponse
source · pub struct UserVanityNameResponse {
pub existed: bool,
}Fields
existed: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.