Struct zoom_api::types::UsersResponse
source · pub struct UsersResponse {Show 19 fields
pub created_at: Option<DateTime<Utc>>,
pub custom_attributes: Vec<UsersResponseCustomAttributes>,
pub dept: String,
pub email: String,
pub first_name: String,
pub group_ids: Vec<String>,
pub host_key: String,
pub id: String,
pub im_group_ids: Vec<String>,
pub last_client_version: String,
pub last_login_time: Option<DateTime<Utc>>,
pub last_name: String,
pub plan_united_type: String,
pub pmi: i64,
pub role_id: String,
pub status: Option<UsersStatus>,
pub timezone: String,
pub type_: i64,
pub verified: i64,
}Fields
created_at: Option<DateTime<Utc>>Account subscription start date and time.
custom_attributes: Vec<UsersResponseCustomAttributes>Information about the user’s custom attributes.
This field is **only** returned if users are assigned custom attributes and you provided the custom_attributes value for the include_fields query parameter in the API request.
dept: StringUser’s first name.
email: StringUser’s first name.
first_name: StringUser’s first name.
group_ids: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.
host_key: StringUser’s first name.
id: StringUser’s first name.
im_group_ids: Vec<String>Specify the IP addresses of the Room Connectors that you would like to share with the sub account. Multiple values can be separated by comma. If no value is provided in this field, all the Room Connectors of a master account will be shared with the sub account.
**Note:** This option can only be used if the value of share_rc is set to true.
last_client_version: StringUser’s first name.
last_login_time: Option<DateTime<Utc>>Account subscription start date and time.
last_name: StringUser’s first name.
plan_united_type: StringUser’s first name.
pmi: i64Account seats.
role_id: StringUser’s first name.
status: Option<UsersStatus>The user’s status:
* active — An active user.
* inactive — A deactivated user.
* pending — A pending user.
This value defaults to active.
timezone: StringUser’s first name.
type_: i64Account seats.
verified: i64Account seats.