Struct zoom_api::types::VideoDeviceCrc
source · pub struct VideoDeviceCrc {
pub avg_loss: String,
pub bitrate: String,
pub jitter: String,
pub latency: String,
pub max_loss: String,
}Expand description
QoS metrics on video output received by a participant who joined the meeting via a Cloud Room Connector.
Fields
avg_loss: StringQoS metrics on video output received by a participant who joined the meeting via a Cloud Room Connector.
bitrate: StringQoS metrics on video output received by a participant who joined the meeting via a Cloud Room Connector.
jitter: StringQoS metrics on video output received by a participant who joined the meeting via a Cloud Room Connector.
latency: StringQoS metrics on video output received by a participant who joined the meeting via a Cloud Room Connector.
max_loss: StringQoS metrics on video output received by a participant who joined the meeting via a Cloud Room Connector.