Struct zoom_api::types::VideoDeviceFromCrc
source · pub struct VideoDeviceFromCrc {
pub avg_loss: String,
pub bitrate: String,
pub jitter: String,
pub latency: String,
pub max_loss: String,
}Expand description
QoS metrics on video input being sent from a Cloud Room Connector used by the participant to join the meeting.
Fields
avg_loss: StringQoS metrics on video input being sent from a Cloud Room Connector used by the participant to join the meeting.
bitrate: StringQoS metrics on video input being sent from a Cloud Room Connector used by the participant to join the meeting.
jitter: StringQoS metrics on video input being sent from a Cloud Room Connector used by the participant to join the meeting.
latency: StringQoS metrics on video input being sent from a Cloud Room Connector used by the participant to join the meeting.
max_loss: StringQoS metrics on video input being sent from a Cloud Room Connector used by the participant to join the meeting.