Struct zoom_api::types::WaitingRoomSettings
source · pub struct WaitingRoomSettings {
pub participants_to_place_in_waiting_room: i64,
pub users_who_can_admit_participants_from_waiting_room: i64,
pub whitelisted_domains_for_waiting_room: String,
}Expand description
Specify the settings to be applied if waiting room is enabled.
Fields
participants_to_place_in_waiting_room: i64Specify the settings to be applied if waiting room is enabled.
users_who_can_admit_participants_from_waiting_room: i64Specify the settings to be applied if waiting room is enabled.
whitelisted_domains_for_waiting_room: StringSpecify the settings to be applied if waiting room is enabled.