Struct zoom_api::types::WebinarCreateResponse
source · pub struct WebinarCreateResponse {
pub host_email: String,
pub host_id: String,
pub id: i64,
pub registrants_confirmation_email: bool,
pub template_id: String,
pub uuid: String,
}Fields
host_email: StringUser’s first name.
host_id: StringUser’s first name.
id: i64Account seats.
registrants_confirmation_email: boolEnable/disable the option for a sub account to use shared Virtual Room Connector(s) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
template_id: StringUser’s first name.
uuid: StringUser’s first name.