Struct zoom_api::types::WebinarCreateResponseAllOf
source · pub struct WebinarCreateResponseAllOf {
pub webinar_info: WebinarInfo,
pub webinar_create_response: WebinarCreateResponse,
}Expand description
All of the following types are flattened into one object:
WebinarInfoWebinarCreateResponse
Fields
webinar_info: WebinarInfoWebinar object.
webinar_create_response: WebinarCreateResponseTrait Implementations
sourceimpl Clone for WebinarCreateResponseAllOf
impl Clone for WebinarCreateResponseAllOf
sourcefn clone(&self) -> WebinarCreateResponseAllOf
fn clone(&self) -> WebinarCreateResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for WebinarCreateResponseAllOf
impl Debug for WebinarCreateResponseAllOf
sourceimpl<'de> Deserialize<'de> for WebinarCreateResponseAllOf
impl<'de> Deserialize<'de> for WebinarCreateResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for WebinarCreateResponseAllOf
impl JsonSchema for WebinarCreateResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<WebinarCreateResponseAllOf> for WebinarCreateResponseAllOf
impl PartialEq<WebinarCreateResponseAllOf> for WebinarCreateResponseAllOf
sourcefn eq(&self, other: &WebinarCreateResponseAllOf) -> bool
fn eq(&self, other: &WebinarCreateResponseAllOf) -> bool
impl StructuralPartialEq for WebinarCreateResponseAllOf