Struct zoom_api::types::WebinarResponseAllOf
source · pub struct WebinarResponseAllOf {
pub webinar_info: WebinarInfo,
pub webinar_response: WebinarResponse,
}Expand description
All of the following types are flattened into one object:
WebinarInfoWebinarResponse
Fields
webinar_info: WebinarInfoWebinar object.
webinar_response: WebinarResponseTrait Implementations
sourceimpl Clone for WebinarResponseAllOf
impl Clone for WebinarResponseAllOf
sourcefn clone(&self) -> WebinarResponseAllOf
fn clone(&self) -> WebinarResponseAllOf
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for WebinarResponseAllOf
impl Debug for WebinarResponseAllOf
sourceimpl<'de> Deserialize<'de> for WebinarResponseAllOf
impl<'de> Deserialize<'de> for WebinarResponseAllOf
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for WebinarResponseAllOf
impl JsonSchema for WebinarResponseAllOf
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<WebinarResponseAllOf> for WebinarResponseAllOf
impl PartialEq<WebinarResponseAllOf> for WebinarResponseAllOf
sourcefn eq(&self, other: &WebinarResponseAllOf) -> bool
fn eq(&self, other: &WebinarResponseAllOf) -> bool
sourceimpl Serialize for WebinarResponseAllOf
impl Serialize for WebinarResponseAllOf
impl StructuralPartialEq for WebinarResponseAllOf