pub struct ChatChannelsAccountLevel {
pub client: Client,
}Fields
client: ClientImplementations
sourceimpl ChatChannelsAccountLevel
impl ChatChannelsAccountLevel
sourcepub async fn get_channel(
&self,
user_id: &str,
channel_id: &str
) -> Result<Channel>
pub async fn get_channel(
&self,
user_id: &str,
channel_id: &str
) -> Result<Channel>
Get a channel.
This function performs a GET to the /chat/users/{userId}/channels/{channelId} endpoint.
Use this API to get information about a specific channel. For user-level apps, pass the me value instead of the userId parameter.
Zoom chat channels allow users to communicate via chat in private or public groups.
Scopes: chat_channel:read:admin
Rate Limit Label: Medium
Note: For an account-level OAuth app, this API can only be used on behalf of a user who is assigned with a role that has the View or Edit permission for Chat Channels.
Parameters:
channel_id: &str– Channel ID: Unique Identifier of a channel.user_id: &str– Unique identifier of the user who is the owner of the channel.
sourcepub async fn delete_channel(&self, user_id: &str, channel_id: &str) -> Result<()>
pub async fn delete_channel(&self, user_id: &str, channel_id: &str) -> Result<()>
Delete a channel.
This function performs a DELETE to the /chat/users/{userId}/channels/{channelId} endpoint.
Use this API to delete a specific channel. For user-level apps, pass the me value instead of the userId parameter.
Zoom chat channels allow users to communicate via chat in private or public groups.
Scopes: chat_channel:write:admin
Rate Limit Label: Medium
Note: This API only supports a user-managed OAuth app.
Parameters:
channel_id: &str– Channel ID: Unique Identifier of a channel.
sourcepub async fn update_channel(
&self,
user_id: &str,
channel_id: &str,
body: &Attendees
) -> Result<()>
pub async fn update_channel(
&self,
user_id: &str,
channel_id: &str,
body: &Attendees
) -> Result<()>
Update a channel.
This function performs a PATCH to the /chat/users/{userId}/channels/{channelId} endpoint.
Use this API to update the name of a specific channel created by a user. For user-level apps, pass the me value instead of the userId parameter.
Zoom chat channels allow users to communicate via chat in private or public channels.
Scopes: chat_channel:write:admin
Rate Limit Label: Medium
Note: For an account-level OAuth app, this API can only be used on behalf of a user who is assigned with a role that has the Edit permission for Chat Channel.
Parameters:
channel_id: &str– User’s first name.user_id: &str– Unique Identifier of the Zoom user who is the owner of the channel.
sourcepub async fn list_channel_members(
&self,
user_id: &str,
channel_id: &str,
page_size: i64,
next_page_token: &str
) -> Result<Vec<ListChannelMembersResponse>>
pub async fn list_channel_members(
&self,
user_id: &str,
channel_id: &str,
page_size: i64,
next_page_token: &str
) -> Result<Vec<ListChannelMembersResponse>>
List channel members.
This function performs a GET to the /chat/users/{userId}/channels/{channelId}/members endpoint.
Use this API to list all members of a channel. For user-level apps, pass the me value instead of the userId parameter.
Scopes: chat_channel:read:admin
Rate Limit Label: Medium
Note: For an account-level OAuth app, this API can only be used on behalf of a user who is assigned with a role that has the View or Edit permission for Chat Channels.
Parameters:
channel_id: &str– User’s first name.page_size: i64– The number of records returned with a single API call.next_page_token: &str– The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.user_id: &str– Unique identifier of the user who is the owner of this channel.
sourcepub async fn list_all_channel_members(
&self,
user_id: &str,
channel_id: &str
) -> Result<Vec<ListChannelMembersResponse>>
pub async fn list_all_channel_members(
&self,
user_id: &str,
channel_id: &str
) -> Result<Vec<ListChannelMembersResponse>>
List channel members.
This function performs a GET to the /chat/users/{userId}/channels/{channelId}/members endpoint.
As opposed to list_channel_members, this function returns all the pages of the request at once.
Use this API to list all members of a channel. For user-level apps, pass the me value instead of the userId parameter.
Scopes: chat_channel:read:admin
Rate Limit Label: Medium
Note: For an account-level OAuth app, this API can only be used on behalf of a user who is assigned with a role that has the View or Edit permission for Chat Channels.
sourcepub async fn invite_channel_members(
&self,
user_id: &str,
channel_id: &str,
body: &InviteChannelMembersRequest
) -> Result<InviteChannelMembersResponse>
pub async fn invite_channel_members(
&self,
user_id: &str,
channel_id: &str,
body: &InviteChannelMembersRequest
) -> Result<InviteChannelMembersResponse>
Invite channel members.
This function performs a POST to the /chat/users/{userId}/channels/{channelId}/members endpoint.
Use this API to invite members that are in a user’s contact list to a channel. For user-level apps, pass the me value instead of the userId parameter.
Scopes: chat_channel:write:admin
Rate Limit Label: Medium
Note: For an account-level OAuth app, this API can only be used on behalf of a user who is assigned with a role that has the Edit permission for Chat Channels.
Parameters:
channel_id: &str– Channel ID: Unique Identifier of the channel.user_id: &str– Unique identifier of the user who is the owner of this channel.
sourcepub async fn remove_channel_member(
&self,
user_id: &str,
channel_id: &str,
member_id: &str
) -> Result<()>
pub async fn remove_channel_member(
&self,
user_id: &str,
channel_id: &str,
member_id: &str
) -> Result<()>
Remove a member.
This function performs a DELETE to the /chat/users/{userId}/channels/{channelId}/members/{memberId} endpoint.
A channel can have one or multiple members. Use this API to remove a member from a chat channel. For user-level apps, pass the me value instead of the userId parameter.
Scopes: chat_channel:write:admin
Rate Limit Label: Medium
Note: For an account-level OAuth app, this API can only be used on behalf of a user who is assigned with a role that has Edit permission for Chat Channels.
Parameters:
channel_id: &str– Unique Identifier of the Channel from where you would like to remove a member. This can be retrieved from the List Channels API.member_id: &str– Email address of the member whom you would like to be remove from the channel.user_id: &str– Unique identifier of the channel owner.