pub struct CommonAreaPhones {
pub client: Client,
}Fields
client: ClientImplementations
Sourceimpl CommonAreaPhones
impl CommonAreaPhones
Sourcepub async fn list(
&self,
page_size: i64,
next_page_token: &str,
) -> Result<Response<Vec<CommonAreaPhones>>, ClientError>
pub async fn list( &self, page_size: i64, next_page_token: &str, ) -> Result<Response<Vec<CommonAreaPhones>>, ClientError>
List common area phones.
This function performs a GET to the /phone/common_area_phones endpoint.
Use this API to list all of an account’s common area phones.
A common area phone can be provisioned by a Zoom account owner or a Zoom admin so that anyone in an organization can use it. For example, if your office has shared desks that don’t belong to a specific employees, you could add a common area phone so that any person can use it.
Scopes: phone:read:admin
Rate Limit Label: Medium
Prerequisites:
- Pro or a higher account with Zoom Phone license.
- Account owner or admin permissions.
- A supported device
Parameters:
page_size: i64– The total number of records returned from a single API call.next_page_token: &str– The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
Sourcepub async fn list_all(
&self,
) -> Result<Response<Vec<CommonAreaPhones>>, ClientError>
pub async fn list_all( &self, ) -> Result<Response<Vec<CommonAreaPhones>>, ClientError>
List common area phones.
This function performs a GET to the /phone/common_area_phones endpoint.
As opposed to list, this function returns all the pages of the request at once.
Use this API to list all of an account’s common area phones.
A common area phone can be provisioned by a Zoom account owner or a Zoom admin so that anyone in an organization can use it. For example, if your office has shared desks that don’t belong to a specific employees, you could add a common area phone so that any person can use it.
Scopes: phone:read:admin
Rate Limit Label: Medium
Prerequisites:
- Pro or a higher account with Zoom Phone license.
- Account owner or admin permissions.
- A supported device
Sourcepub async fn add(
&self,
body: &AddCommonAreaPhoneRequest,
) -> Result<Response<AddCommonAreaPhoneResponse>, ClientError>
pub async fn add( &self, body: &AddCommonAreaPhoneRequest, ) -> Result<Response<AddCommonAreaPhoneResponse>, ClientError>
Add a common area phone.
This function performs a POST to the /phone/common_area_phones endpoint.
Use this API to add a common area phone.
A common area phone can be provisioned by a Zoom account owner or a Zoom admin so that anyone in an organization can use it. For example, if your office has shared desks that don’t belong to a specific employees, you could add a common area phone so that any person can use it.
Scopes: phone:write:admin
Rate Limit Label: Light
Prerequisites:
- Pro or a higher account with Zoom Phone license
- Account owner or admin permissions
- A supported device
Sourcepub async fn get(
&self,
common_area_phone_id: &str,
) -> Result<Response<GetCommonAreaPhoneResponse>, ClientError>
pub async fn get( &self, common_area_phone_id: &str, ) -> Result<Response<GetCommonAreaPhoneResponse>, ClientError>
Get common area phone details.
This function performs a GET to the /phone/common_area_phones/{commonAreaPhoneId} endpoint.
Use this API to get details on a specific common area phone in an account.
A common area phone can be provisioned by a Zoom account owner or a Zoom admin so that anyone in an organization can use it. For example, if your office has shared desks that don’t belong to a specific employees, you could add a common area phone so that any person can use it.
Scopes: phone:read:admin
Rate Limit Label: Light
Prerequisites:
- Pro or a higher account with Zoom Phone license
- Account owner or admin permissions
- A supported device
Parameters:
common_area_phone_id: &str– Unique Identifier of the Common Area Phone. Use the unique identifier or the Mac address of the common area phone. The Mac address can be in hyphenated (00-04-f2-5e-ec-3c) or not hyphenated (0004f25eec3c) format. You can get this value from the List Common Area Phones API.
Sourcepub async fn delete(
&self,
common_area_phone_id: &str,
) -> Result<Response<()>, ClientError>
pub async fn delete( &self, common_area_phone_id: &str, ) -> Result<Response<()>, ClientError>
Delete a common area phone.
This function performs a DELETE to the /phone/common_area_phones/{commonAreaPhoneId} endpoint.
A common area phone can be provisioned by a Zoom account owner or a Zoom admin so that anyone in an organization can use it. For example, if your office has shared desks that don’t belong to a specific employees, you could add a common area phone so that any person can use it.
Use this API to remove the common area phone from Zoom Phone System in an account.
Prerequisites:
- Pro or a higher account with Zoom Phone license.
- Account owner or admin permissions.
- Supported device
Scopes:phone:write:admin
Rate Limit Label: Light
Parameters:
common_area_phone_id: &str– Unique Identifier of the common area phone.
Sourcepub async fn update(
&self,
common_area_phone_id: &str,
body: &UpdateCommonAreaPhoneRequest,
) -> Result<Response<()>, ClientError>
pub async fn update( &self, common_area_phone_id: &str, body: &UpdateCommonAreaPhoneRequest, ) -> Result<Response<()>, ClientError>
Update common area phone.
This function performs a PATCH to the /phone/common_area_phones/{commonAreaPhoneId} endpoint.
Use this API to update details on a specific common area phone in an account.
A common area phone can be provisioned by a Zoom account owner or a Zoom admin so that anyone in an organization can use it. For example, if your office has shared desks that don’t belong to a specific employees, you could add a common area phone so that any person can use it.
Scopes: phone:write:admin
Rate Limit Label: Light
Prerequisites:
- Pro or a higher account with Zoom Phone license
- Account owner or admin permissions
- A supported device
Sourcepub async fn assign_phone_numbers_common_area(
&self,
common_area_phone_id: &str,
body: &AssignPhoneNumbersCommonAreaRequest,
) -> Result<Response<AssignPhoneNumbersCommonAreaResponseData>, ClientError>
pub async fn assign_phone_numbers_common_area( &self, common_area_phone_id: &str, body: &AssignPhoneNumbersCommonAreaRequest, ) -> Result<Response<AssignPhoneNumbersCommonAreaResponseData>, ClientError>
Assign phone numbers to common area phone.
This function performs a POST to the /phone/common_area_phones/{commonAreaPhoneId}/phone_numbers endpoint.
Assign phone numbers to common area phone.
Prerequisites:
- Pro or a higher account with Zoom Phone license.
- Account owner or admin permissions.
Scope:
phone:write:admin
Rate Limit Label: Light
Sourcepub async fn unassign_phone_numbers_from_common_area(
&self,
common_area_phone_id: &str,
phone_number_id: &str,
) -> Result<Response<()>, ClientError>
pub async fn unassign_phone_numbers_from_common_area( &self, common_area_phone_id: &str, phone_number_id: &str, ) -> Result<Response<()>, ClientError>
Unassign phone numbers from a common area phone.
This function performs a DELETE to the /phone/common_area_phones/{commonAreaPhoneId}/phone_numbers/{phoneNumberId} endpoint.
Use this API to unassign a phone number from a common Area phone.
Scopes: phone:write:admin
Rate Limit Label: Light
Prerequisites:
- A Pro or a higher account with a Zoom Phone license
- An account owner or admin permissions
Parameters:
common_area_phone_id: &str– The common area phone’s unique ID.phone_number_id: &str– The phone number or the phone number’s unique ID.
Sourcepub async fn assign_calling_plans(
&self,
common_area_phone_id: &str,
body: &AssignCallingPlansCommonAreaPhoneRequestData,
) -> Result<Response<AssignCallingPlansCommonAreaPhoneResponseData>, ClientError>
pub async fn assign_calling_plans( &self, common_area_phone_id: &str, body: &AssignCallingPlansCommonAreaPhoneRequestData, ) -> Result<Response<AssignCallingPlansCommonAreaPhoneResponseData>, ClientError>
Assign calling plans to common area phone.
This function performs a POST to the /phone/common_area_phones/{commonAreaPhoneId}/calling_plans endpoint.
Assign calling plans to common area phone.
Prerequisites:
- Pro or a higher account with Zoom Phone license.
- Account owner or admin permissions.
Scope:
phone:write:admin
Rate Limit Label: Light
Sourcepub async fn unassign_calling_plans_from(
&self,
common_area_phone_id: &str,
type_: &str,
) -> Result<Response<()>, ClientError>
pub async fn unassign_calling_plans_from( &self, common_area_phone_id: &str, type_: &str, ) -> Result<Response<()>, ClientError>
Unassign calling plan from a common area phone.
This function performs a DELETE to the /phone/common_area_phones/{commonAreaPhoneId}/calling_plans/{type} endpoint.
Use this API to unassign a calling plan from a common area phone.
Scopes: phone:write:admin
Rate Limit Label: Light
Prerequisites:
- A Pro or higher account with a Zoom Phone license
- An account owner or admin permissions
Parameters:
common_area_phone_id: &str– The common area phone’s unique ID.type_: &str– The calling plan to remove.