pub struct Pac {
pub client: Client,
}Fields
client: ClientImplementations
sourceimpl Pac
impl Pac
sourcepub async fn user_pa_cs(&self, user_id: &str) -> Result<UserPaCsResponse>
pub async fn user_pa_cs(&self, user_id: &str) -> Result<UserPaCsResponse>
List a user’s PAC accounts.
This function performs a GET to the /users/{userId}/pac endpoint.
Use this API to list a user’s Personal Audio Conference accounts. For user-level apps, pass the me value instead of the userId parameter.
PAC allows Pro or higher account holders to host meetings through PSTN (phone dial-in) only.
Scopes: pac:read:admin, pac:read
Rate Limit Label: Light
Prerequisites:
- A Pro or higher plan with Premium Audio Conferencing add-on.
- Personal Audio Conference must be enabled in the user’s profile.
Parameters:
user_id: &str– The user ID or email address of the user. For user-level apps, passmeas the value for userId.