pub struct PhoneAutoReceptionists {
pub client: Client,
}Fields
client: ClientImplementations
sourceimpl PhoneAutoReceptionists
impl PhoneAutoReceptionists
sourcepub async fn update_auto_receptionist(
&self,
auto_receptionist_id: &str,
body: &UpdateAutoReceptionistRequest
) -> Result<()>
pub async fn update_auto_receptionist(
&self,
auto_receptionist_id: &str,
body: &UpdateAutoReceptionistRequest
) -> Result<()>
Update auto receptionist details.
This function performs a PATCH to the /phone/auto_receptionists/{autoReceptionistId} endpoint.
An auto receptionist answers calls with a personalized recording and routes calls to a phone user, call queue, common area phone, or voicemail. An auto receptionist can also be set up so that it routes calls to an interactive voice response (IVR) system to allow callers to select the routing options.
Use this API to change information such as display name and extension number assigned to the main auto receptionist.
Prerequisites:
- Pro or higher account with Zoom Phone license.
Scopes:phone:write:admin
Rate Limit Label: Light
Parameters:
auto_receptionist_id: &str– Unique Identifier of the Auto Receptionist. It can be retrieved from the List Sites API.
sourcepub async fn assign_phone_numbers_auto_receptionist(
&self,
auto_receptionist_id: &str,
body: &AddByocNumberResponse
) -> Result<()>
pub async fn assign_phone_numbers_auto_receptionist(
&self,
auto_receptionist_id: &str,
body: &AddByocNumberResponse
) -> Result<()>
Assign phone numbers.
This function performs a POST to the /phone/auto_receptionists/{autoReceptionistId}/phone_numbers endpoint.
Assign available phone numbers to an auto receptionist. The available numbers can be retrieved using the List Phone Numbers API with type query parameter set to “unassigned”.
Prerequisites:
- Pro or higher account plan with Zoom Phone License
- Account owner or admin permissions
Scopes:phone:write:admin
Rate Limit Label: Light
Parameters:
auto_receptionist_id: &str– Unique Identifier of the Auto Receptionist. It can be retrieved from the List Sites API.
sourcepub async fn unassign_all_phone_nums_auto_receptionist(
&self,
auto_receptionist_id: &str
) -> Result<()>
pub async fn unassign_all_phone_nums_auto_receptionist(
&self,
auto_receptionist_id: &str
) -> Result<()>
Unassign all phone numbers.
This function performs a DELETE to the /phone/auto_receptionists/{autoReceptionistId}/phone_numbers endpoint.
Unassign all phone numbers that were previously assigned to an auto receptionist.
Prerequisites:
- Pro or higher account plan with Zoom Phone License
- Account owner or admin permissions
Scopes:phone:write:admin
Rate Limit Label: Light
sourcepub async fn unassign_phone_num_auto_receptionist(
&self,
auto_receptionist_id: &str,
phone_number_id: &str
) -> Result<()>
pub async fn unassign_phone_num_auto_receptionist(
&self,
auto_receptionist_id: &str,
phone_number_id: &str
) -> Result<()>
Unassign a phone number.
This function performs a DELETE to the /phone/auto_receptionists/{autoReceptionistId}/phone_numbers/{phoneNumberId} endpoint.
Unassign a specific phone number that was previously assigned to an auto receptionist.
Prerequisites:
- Pro or higher account plan with Zoom Phone License
- Account owner or admin permissions
Scopes:phone:write:admin
Rate Limit Label: Light
Parameters:
auto_receptionist_id: &str– Unique identifier of the auto receptionist. This can be retrieved from the List Phone Sites API.phone_number_id: &str– Unique Identifier of the phone number or provide the actual phone number in e164 format (example: +19995550123).
sourcepub async fn add_auto_receptionist(
&self,
body: &AddAutoReceptionistRequest
) -> Result<AddAutoReceptionistResponse>
pub async fn add_auto_receptionist(
&self,
body: &AddAutoReceptionistRequest
) -> Result<AddAutoReceptionistResponse>
Add an auto receptionist.
This function performs a POST to the /phone/auto_receptionists endpoint.
Auto receptionists answer calls with a personalized recording and routes calls to a phone user, call queue, common area phone, voicemail or an IVR system. Use this API to add an auto receptionist to a Zoom Phone.
Prerequisites:
- Pro or higher account with Zoom Phone license.
Scopes:phone:write:admin
Rate Limit Label:Light