pub struct PhoneSharedLineGroups {
pub client: Client,
}Fields
client: ClientImplementations
List shared line groups.
This function performs a GET to the /phone/shared_line_groups endpoint.
A shared line group allows Zoom Phone admins to share a phone number and extension with a group of phone users or common area phones. This gives members of the shared line group access to the group’s direct phone number and voicemail. Use this API to list all the Shared Line Groups.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- Account owner or admin privileges
Scopes: phone:read:admin, phone:write:admin
Rate Limit Label: Medium
Parameters:
page_size: i64– The number of records returned within a single API call.next_page_token: &str– The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
List shared line groups.
This function performs a GET to the /phone/shared_line_groups endpoint.
As opposed to list_shared_line_groups, this function returns all the pages of the request at once.
A shared line group allows Zoom Phone admins to share a phone number and extension with a group of phone users or common area phones. This gives members of the shared line group access to the group’s direct phone number and voicemail. Use this API to list all the Shared Line Groups.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- Account owner or admin privileges
Scopes: phone:read:admin, phone:write:admin
Rate Limit Label: Medium
Create a shared line group.
This function performs a POST to the /phone/shared_line_groups endpoint.
A shared line group allows Zoom Phone admins to share a phone number and extension with a group of phone users or common area phones. This gives members of the shared line group access to the group’s direct phone number and voicemail. Use this API to create a shared line group.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- Account owner or admin privileges
Scopes: phone:write:admin
Rate Limit Label: Light
Get a shared line group.
This function performs a GET to the /phone/shared_line_groups/{sharedLineGroupId} endpoint.
A shared line group allows Zoom Phone admins to share a phone number and extension with a group of phone users or common area phones. This gives members of the shared line group access to the group’s direct phone number and voicemail. Use this API to list all the Shared Line Groups.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- Account owner or admin privileges
Scopes: phone:read:admin or phone:write:admin
Rate Limit Label: Light
Parameters:
shared_line_group_id: &str– Unique Identifier of the Shared Line Group.
Delete a shared line group.
This function performs a DELETE to the /phone/shared_line_groups/{sharedLineGroupId} endpoint.
A shared line group allows Zoom Phone admins to share a phone number and extension with a group of phone users or common area phones. Use this API to delete a Shared Line Group.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- Account owner or admin privileges
Scopes: phone:write:admin
Rate Limit Label: Light
Parameters:
shared_line_group_id: &str– Unique Identifier of the shared line group that you would like to delete.
Update a shared line group.
This function performs a PATCH to the /phone/shared_line_groups/{sharedLineGroupId} endpoint.
A shared line group allows Zoom Phone admins to share a phone number and extension with a group of phone users or common area phones. This gives members of the shared line group access to the group’s direct phone number and voicemail. Use this API to update information of a Shared Line Group.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- Account owner or admin privileges
Scopes: phone:write:admin
Rate Limit Label: Light
Parameters:
shared_line_group_id: &str– Unique identifier of the shared line group that is to be updated.
Add members to a shared line group.
This function performs a POST to the /phone/shared_line_groups/{sharedLineGroupId}/members endpoint.
A shared line group allows Zoom Phone admins to share a phone number and extension with a group of phone users or common area phones. This gives members of the shared line group access to the group’s direct phone number and voicemail. Use this API to add members to a Shared Line Group. Note that a member can only be added to one shared line group.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- A valid Shared Line Group
- Account owner or admin privileges
Scopes: phone:write:admin
Rate Limit Label: Light
Parameters:
shared_line_group_id: &str– Unique Identifier of the shared line group.
Sourcepub async fn delete_members_of_slg(
&self,
shared_line_group_id: &str,
) -> Result<Response<()>, ClientError>
pub async fn delete_members_of_slg( &self, shared_line_group_id: &str, ) -> Result<Response<()>, ClientError>
Unassign members of a shared line group.
This function performs a DELETE to the /phone/shared_line_groups/{sharedLineGroupId}/members endpoint.
Members of the shared line group have access to the group’s phone number and voicemail. Use this API to unassign all the existing members from a Shared Line Group.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- A valid Shared Line Group
- Account owner or admin privileges
Scopes: phone:write:admin
Rate Limit Label: Light
Parameters:
shared_line_group_id: &str– Unique identifier of the Shared Line Group that you would like to delete.
Sourcepub async fn delete_member_slg(
&self,
shared_line_group_id: &str,
member_id: &str,
) -> Result<Response<()>, ClientError>
pub async fn delete_member_slg( &self, shared_line_group_id: &str, member_id: &str, ) -> Result<Response<()>, ClientError>
Unassign a member from a shared line group.
This function performs a DELETE to the /phone/shared_line_groups/{sharedLineGroupId}/members/{memberId} endpoint.
Members of the shared line group have access to the group’s phone number and voicemail. Use this API to unassign a specific member from a Shared Line Group.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- A valid Shared Line Group
- Account owner or admin privileges
Scopes: phone:write:admin
Rate Limit Label: Light
Parameters:
shared_line_group_id: &str– Unique Identifier of the shared line group from which you would like to remove a member.member_id: &str– Unique identifier of the member who is to be removed.
Sourcepub async fn assign_phone_numbers_slg(
&self,
shared_line_group_id: &str,
body: &AddByocNumberResponse,
) -> Result<Response<()>, ClientError>
pub async fn assign_phone_numbers_slg( &self, shared_line_group_id: &str, body: &AddByocNumberResponse, ) -> Result<Response<()>, ClientError>
Assign phone numbers.
This function performs a POST to the /phone/shared_line_groups/{sharedLineGroupId}/phone_numbers endpoint.
Use this API to assign phone numbers to a shared line groups. These direct phone numbers will be shared among members of the shared line group.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- A valid Shared Line Group
- Account owner or admin privileges
Scopes: phone:write:admin
Rate Limit Label: Light
Parameters:
shared_line_group_id: &str– Unique Identifier of the Shared Line Group.
Sourcepub async fn delete_phone_numbers_slg(
&self,
shared_line_group_id: &str,
) -> Result<Response<()>, ClientError>
pub async fn delete_phone_numbers_slg( &self, shared_line_group_id: &str, ) -> Result<Response<()>, ClientError>
Unassign all phone numbers.
This function performs a DELETE to the /phone/shared_line_groups/{sharedLineGroupId}/phone_numbers endpoint.
Use this API to unassign all the phone numbers that have been assigned to the shared line group.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- A valid Shared Line Group
- Account owner or admin privileges
Scopes: phone:write:admin
Rate Limit Label: Light
Parameters:
shared_line_group_id: &str– Unique Identifier of the Shared Line Group.
Sourcepub async fn delete_phone_number_slg(
&self,
shared_line_group_id: &str,
phone_number_id: &str,
) -> Result<Response<()>, ClientError>
pub async fn delete_phone_number_slg( &self, shared_line_group_id: &str, phone_number_id: &str, ) -> Result<Response<()>, ClientError>
Unassign a phone number.
This function performs a DELETE to the /phone/shared_line_groups/{sharedLineGroupId}/phone_numbers/{phoneNumberId} endpoint.
Use this API to unassign a specific phone number that was assigned to the shared line group.
Prerequisties:
- Pro or higher account with Zoom Phone license.
- A valid Shared Line Group
- Account owner or admin privileges
Scopes: phone:write:admin
Rate Limit Label: Light
Parameters:
shared_line_group_id: &str– Unique identifier of the shared line group from which you would like to unassign a phone number.phone_number_id: &str– Unique identifier of the phone number which is to be unassigned. This can be retrieved from Get a Shared Line Group API.