Struct zoom_api::phone_site::PhoneSite
source · pub struct PhoneSite {
pub client: Client,
}Fields
client: ClientImplementations
sourceimpl PhoneSite
impl PhoneSite
sourcepub async fn list(
&self,
page_size: i64,
next_page_token: &str
) -> Result<Vec<Sites>>
pub async fn list(
&self,
page_size: i64,
next_page_token: &str
) -> Result<Vec<Sites>>
List phone sites.
This function performs a GET to the /phone/sites endpoint.
Sites allow you to organize Zoom Phone users in your organization. Use this API to list all the sites that have been created for an account.
Prerequisites:
- Multiple Sites must be enabled.
- Pro or a higher account with Zoom Phone enabled.
Scope: phone:read:admin
Rate Limit Label: Medium
Parameters:
page_size: i64– The number of records returned within a single API call.next_page_token: &str– The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
sourcepub async fn list_all(&self) -> Result<Vec<Sites>>
pub async fn list_all(&self) -> Result<Vec<Sites>>
List phone sites.
This function performs a GET to the /phone/sites endpoint.
As opposed to list, this function returns all the pages of the request at once.
Sites allow you to organize Zoom Phone users in your organization. Use this API to list all the sites that have been created for an account.
Prerequisites:
- Multiple Sites must be enabled.
- Pro or a higher account with Zoom Phone enabled.
Scope: phone:read:admin
Rate Limit Label: Medium
sourcepub async fn create(&self, body: &CreatePhoneSiteRequest) -> Result<Site>
pub async fn create(&self, body: &CreatePhoneSiteRequest) -> Result<Site>
Create a phone site.
This function performs a POST to the /phone/sites endpoint.
Sites allow you to organize Zoom Phone users in your organization. Use this API to create a Site.
Prerequisites:
- Multiple Sites must be enabled.
- Pro or a higher account with Zoom Phone enabled.
Scope:
phone:write:admin
Rate Limit Label: Light
sourcepub async fn get_site(&self, site_id: &str) -> Result<GetSiteResponse>
pub async fn get_site(&self, site_id: &str) -> Result<GetSiteResponse>
Get phone site details.
This function performs a GET to the /phone/sites/{siteId} endpoint.
Sites allow you to organize Zoom Phone users in your organization. Use this API to get information about a specific site.
Prerequisites:
- Account must have a Pro or a higher plan with Zoom Phone license.
- Multiple Sites must be enabled.
Scope:phone:read:admin
Rate Limit Label:Light
Parameters:
site_id: &str– Unique Identifier of the Site.
sourcepub async fn delete(&self, site_id: &str, transfer_site_id: &str) -> Result<()>
pub async fn delete(&self, site_id: &str, transfer_site_id: &str) -> Result<()>
Delete a phone site.
This function performs a DELETE to the /phone/sites/{siteId} endpoint.
Sites allow you to organize Zoom Phone users in your organization. Use this API to delete a specific site in a Zoom account. To delete a site, in the query parameter, you must provide the Site ID of another site where the assets of current site (users, numbers and phones) can be transferred to. You cannot use this API to delete the main site.
Prerequisites:
- Account must have a Pro or a higher plan with Zoom Phone license.
- Multiple Sites must be enabled.
Scope:phone:write:admin
Rate Limit Label:Light
Parameters:
site_id: &str– Unique Identifier of the Site.transfer_site_id: &str– The Site ID of another site where the assets of the current site (users, numbers and phones) can be transferred to.
sourcepub async fn update_site_details(
&self,
site_id: &str,
body: &UpdateSiteDetailsRequest
) -> Result<()>
pub async fn update_site_details(
&self,
site_id: &str,
body: &UpdateSiteDetailsRequest
) -> Result<()>
Update phone site details.
This function performs a PATCH to the /phone/sites/{siteId} endpoint.
Sites allow you to organize Zoom Phone users in your organization. Use this API to update information about a specific site.
Prerequisites:
- Account must have a Pro or a higher plan with Zoom Phone license.
- Scope:
phone:write:admin
Rate Limit Label:Light
Parameters:
site_id: &str– Unique Identifier of the Site.