pub struct SipPhone {
pub client: Client,
}Fields
client: ClientImplementations
sourceimpl SipPhone
impl SipPhone
sourcepub async fn list(
&self,
page_number: i64,
search_key: &str,
page_size: i64,
next_page_token: &str
) -> Result<Vec<Phones>>
pub async fn list(
&self,
page_number: i64,
search_key: &str,
page_size: i64,
next_page_token: &str
) -> Result<Vec<Phones>>
List SIP phones.
This function performs a GET to the /sip_phones endpoint.
Zoom’s Phone System Integration (PSI), also referred as SIP phones, enables an organization to leverage the Zoom client to complete a softphone registration to supported premise based PBX system. End users will have the ability to have softphone functionality within a single client while maintaining a comparable interface to Zoom Phone. Use this API to list SIP phones on an account.
Prerequisites:
- Currently only supported on Cisco and Avaya PBX systems.
- User must enable SIP Phone Integration by contacting the Sales team.
Scope:sip_phone:read:admin
Rate Limit Label:Medium
Parameters:
-
page_number: i64– Deprecated - This field has been deprecated and we will stop supporting it completely in a future release. Please use “next_page_token” for pagination instead of this field.The page number of the current page in the returned records.
-
search_key: &str– User name or email address of a user. If this parameter is provided, only the SIP phone system integration enabled for that specific user will be returned. Otherwise, all SIP phones on an account will be returned. -
page_size: i64– The number of records returned within a single API call. -
next_page_token: &str– The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
sourcepub async fn list_all(&self, search_key: &str) -> Result<Vec<Phones>>
pub async fn list_all(&self, search_key: &str) -> Result<Vec<Phones>>
List SIP phones.
This function performs a GET to the /sip_phones endpoint.
As opposed to list, this function returns all the pages of the request at once.
Zoom’s Phone System Integration (PSI), also referred as SIP phones, enables an organization to leverage the Zoom client to complete a softphone registration to supported premise based PBX system. End users will have the ability to have softphone functionality within a single client while maintaining a comparable interface to Zoom Phone. Use this API to list SIP phones on an account.
Prerequisites:
- Currently only supported on Cisco and Avaya PBX systems.
- User must enable SIP Phone Integration by contacting the Sales team.
Scope:sip_phone:read:admin
Rate Limit Label:Medium
sourcepub async fn create(&self, body: &CreateSipPhoneRequest) -> Result<()>
pub async fn create(&self, body: &CreateSipPhoneRequest) -> Result<()>
Enable SIP phone.
This function performs a POST to the /sip_phones endpoint.
Zoom’s Phone System Integration (PSI), also referred as SIP phones, enables an organization to leverage the Zoom client to complete a softphone registration to supported premise based PBX system. End users will have the ability to have softphone functionality within a single client while maintaining a comparable interface to Zoom Phone. Use this API to enable a user to use SIP phone.
Prerequisites:
- Currently only supported on Cisco and Avaya PBX systems.
- The account owner or account admin must first enable SIP Phone Integration by contacting the Sales team.
Scope:sip_phone:write:admin
Rate Limit Label:Light
sourcepub async fn delete(&self, phone_id: &str) -> Result<()>
pub async fn delete(&self, phone_id: &str) -> Result<()>
Delete SIP phone.
This function performs a DELETE to the /sip_phones/{phoneId} endpoint.
Zoom’s Phone System Integration (PSI), also referred as SIP phones, enables an organization to leverage the Zoom client to complete a softphone registration to supported premise based PBX system. End users will have the ability to have softphone functionality within a single client while maintaining a comparable interface to Zoom Phone. Use this API to delete a specific SIP phone on a Zoom account.
Prerequisites:
- Currently only supported on Cisco and Avaya PBX systems.
- User must enable SIP Phone Integration by contacting the Sales team.
Scope:sip_phone:read:admin
Rate Limit Label:Light
Parameters:
phone_id: &str– Unique Identifier of the SIP Phone. It can be retrieved from the List SIP Phones API.
sourcepub async fn update(
&self,
phone_id: &str,
body: &UpdateSipPhoneRequest
) -> Result<()>
pub async fn update(
&self,
phone_id: &str,
body: &UpdateSipPhoneRequest
) -> Result<()>
Update SIP phone.
This function performs a PATCH to the /sip_phones/{phoneId} endpoint.
Zoom’s Phone System Integration (PSI), also referred as SIP phones, enables an organization to leverage the Zoom client to complete a softphone registration to supported premise based PBX system. End users will have the ability to have softphone functionality within a single client while maintaining a comparable interface to Zoom Phone. Use this API to update information of a specific SIP Phone on a Zoom account.
Prerequisites:
- Currently only supported on Cisco and Avaya PBX systems.
- The account owner or account admin must first enable SIP Phone Integration by contacting the Sales team.
Scope:sip_phone:write:admin
Rate Limit Label:Light
Parameters:
phone_id: &str– Unique Identifier of the SIP Phone. This can be retrieved from the List SIP Phones API.