pub struct User {
pub created_at: Option<DateTime<Utc>>,
pub dept: String,
pub email: String,
pub first_name: String,
pub last_client_version: String,
pub last_login_time: Option<DateTime<Utc>>,
pub last_name: String,
pub pmi: i64,
pub role_name: String,
pub timezone: String,
pub type_: i64,
pub use_pmi: bool,
}Expand description
The user object represents a specific user on Zoom.
Fields
created_at: Option<DateTime<Utc>>The user object represents a specific user on Zoom.
dept: StringThe user object represents a specific user on Zoom.
email: StringUser’s first name.
first_name: StringThe user object represents a specific user on Zoom.
last_client_version: StringThe user object represents a specific user on Zoom.
last_login_time: Option<DateTime<Utc>>The user object represents a specific user on Zoom.
last_name: StringThe user object represents a specific user on Zoom.
pmi: i64The user object represents a specific user on Zoom.
role_name: StringThe user object represents a specific user on Zoom.
timezone: StringThe user object represents a specific user on Zoom.
type_: i64Account seats.
use_pmi: boolThe user object represents a specific user on Zoom.